(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53308,       1372]*)
(*NotebookOutlinePosition[     53952,       1394]*)
(*  CellTagsIndexPosition[     53908,       1390]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    StyleBox[\(Off[General::spell]\),
      FormatType->StandardForm,
      FontFamily->"Courier New"], "\n", 
    StyleBox[\(Off[General::spell1]\),
      FormatType->StandardForm,
      FontFamily->"Courier New"]}], "Input"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
General transient temperature solution with negligible internal resistance\
\>", "Section"],

Cell[BoxData[{
    \(\(a = h\ A/\((rho\ c\ V)\);\)\), "\[IndentingNewLine]", 
    \(\(b = Q/\((rho\ c\ V)\) + h\ A\ Tinf/\((rho\ c\ V)\);\)\)}], "Input"],

Cell[BoxData[
    \(\(f = 
        DSolve[{\(T'\)[t] + a\ T[t]\  == \ b, T[0] \[Equal] T0}, T[t], 
          t];\)\)], "Input"],

Cell[BoxData[
    \(g[t_] := Evaluate[f[\([1, 1, 2]\)] + Q\ Rm]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[g[t]]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(A\ h\ t\)\/\(c\ rho\ V\)\)\)\ \((Q\ \((\(-1\) \
+ \[ExponentialE]\^\(\(A\ h\ t\)\/\(c\ rho\ V\)\)\ \((1 + A\ h\ Rm)\))\) + A\ \
h\ \((T0 + \((\(-1\) + \[ExponentialE]\^\(\(A\ h\ t\)\/\(c\ rho\ V\)\))\)\ \
Tinf)\))\)\)\/\(A\ h\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Thermal Time Constant Calculation for Stage 0-1 Actuator Coils -- cool down \
in bake oven\
\>", "Section"],

Cell["\<\
R = total resistance (at low temperature/power, dominated by conduction), C/W \
(guess)
V = actuator volume, m^3 (guess)
A = actuator contact area for conduction, m^2 (guess)
k = thermal conductivity, W/m/K
rho = density, kg/m^3
c= specific heat, J/kg\
\>", "Text"],

Cell[BoxData[
    \(\(R = 10;\)\)], "Input"],

Cell[BoxData[{
    \(\(c = 500;\)\), "\[IndentingNewLine]", 
    \(\(rho = 8030;\)\), "\[IndentingNewLine]", 
    \(\(V = \((2\ \((4.25)\)\ \((7)\) + \ 
              2\ \ \((5.5)\)\ \((4.25)\))\)\ \((0.5)\)\ \((0.0254)\)^3;\)\), \
"\[IndentingNewLine]", 
    \(\(A = 0.1\ \((2)\)\ 7\ \((0.0254)\)^2;\)\), "\[IndentingNewLine]", 
    \(\(h = 1/\((R\ A)\);\)\), "\[IndentingNewLine]", 
    \(\(Q = 0;\)\), "\[IndentingNewLine]", 
    \(\(T0 = 150;\)\), "\[IndentingNewLine]", 
    \(\(Tinf = 28;\)\), "\[IndentingNewLine]", 
    \(\(k = 14;\)\)}], "Input"],

Cell[BoxData[{
    \(\(a = h\ A/\((rho\ c\ V)\);\)\), "\[IndentingNewLine]", 
    \(\(b = Q/\((rho\ c\ V)\) + h\ A\ Tinf/\((rho\ c\ V)\);\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L = V/A;\)\), "\[IndentingNewLine]", 
    \(Bi = h\ L/k\)}], "Input"],

Cell[BoxData[
    \(7.6222136773719615`\)], "Output"]
}, Open  ]],

Cell["Biot Number < 0.05 for this approximation??", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(diff = k/\((c\ rho)\);\)\), "\[IndentingNewLine]", 
    \(Bi\ diff/L^2\)}], "Input"],

Cell[BoxData[
    \(0.000028609769409295035`\)], "Output"]
}, Open  ]],

Cell["Time constant in hours:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theta = \((rho\ c\ L)\)/\((h\ 60^2)\)\)], "Input"],

Cell[BoxData[
    \(9.709193171180557`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - 1/E\  // N\)], "Input"],

Cell[BoxData[
    \(0.6321205588285577`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(0.63\ 150\  + 20\)], "Input"],

Cell[BoxData[
    \(114.5`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(27.216\ 60^2\)], "Input"],

Cell[BoxData[
    \(97977.6`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f = 
        DSolve[{\(T'\)[t] + a\ T[t]\  == \ b, T[0] \[Equal] T0}, T[t], 
          t];\)\)], "Input"],

Cell[BoxData[
    \(g[t_] := Evaluate[f[\([1, 1, 2]\)] + Q\ Rm]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[g[t]]\)], "Input"],

Cell[BoxData[
    \(\(\(27.999999999999996`\)\(\[InvisibleSpace]\)\) + 
      122.`\ \[ExponentialE]\^\(\(-0.000028609769409295038`\)\ t\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T0 + Q\ R\)], "Input"],

Cell[BoxData[
    \(150\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[0]\)], "Input"],

Cell[BoxData[
    \(150.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[10^6]\)], "Input"],

Cell[BoxData[
    \(28.000000000045844`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T0 + Q/\((h\ A)\)\)], "Input"],

Cell[BoxData[
    \(150\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Q\ Rm\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[14\ 3600]\)], "Input"],

Cell[BoxData[
    \(56.84938473849776`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g[t], {t, 0, 3\ theta\ 60^2}, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.08247e-006 -0.158293 0.00507741 [
[.20546 .0323 -15 -9 ]
[.20546 .0323 15 0 ]
[.38711 .0323 -15 -9 ]
[.38711 .0323 15 0 ]
[.56876 .0323 -15 -9 ]
[.56876 .0323 15 0 ]
[.75041 .0323 -15 -9 ]
[.75041 .0323 15 0 ]
[.93206 .0323 -18 -9 ]
[.93206 .0323 18 0 ]
[.01131 .14635 -12 -4.5 ]
[.01131 .14635 0 4.5 ]
[.01131 .2479 -12 -4.5 ]
[.01131 .2479 0 4.5 ]
[.01131 .34945 -18 -4.5 ]
[.01131 .34945 0 4.5 ]
[.01131 .451 -18 -4.5 ]
[.01131 .451 0 4.5 ]
[.01131 .55254 -18 -4.5 ]
[.01131 .55254 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20546 .0448 m
.20546 .05105 L
s
[(20000)] .20546 .0323 0 1 Mshowa
.38711 .0448 m
.38711 .05105 L
s
[(40000)] .38711 .0323 0 1 Mshowa
.56876 .0448 m
.56876 .05105 L
s
[(60000)] .56876 .0323 0 1 Mshowa
.75041 .0448 m
.75041 .05105 L
s
[(80000)] .75041 .0323 0 1 Mshowa
.93206 .0448 m
.93206 .05105 L
s
[(100000)] .93206 .0323 0 1 Mshowa
.125 Mabswid
.06922 .0448 m
.06922 .04855 L
s
.11463 .0448 m
.11463 .04855 L
s
.16005 .0448 m
.16005 .04855 L
s
.25087 .0448 m
.25087 .04855 L
s
.29628 .0448 m
.29628 .04855 L
s
.3417 .0448 m
.3417 .04855 L
s
.43252 .0448 m
.43252 .04855 L
s
.47793 .0448 m
.47793 .04855 L
s
.52335 .0448 m
.52335 .04855 L
s
.61417 .0448 m
.61417 .04855 L
s
.65958 .0448 m
.65958 .04855 L
s
.70499 .0448 m
.70499 .04855 L
s
.79582 .0448 m
.79582 .04855 L
s
.84123 .0448 m
.84123 .04855 L
s
.88664 .0448 m
.88664 .04855 L
s
.97747 .0448 m
.97747 .04855 L
s
.25 Mabswid
0 .0448 m
1 .0448 L
s
.02381 .14635 m
.03006 .14635 L
s
[(60)] .01131 .14635 1 0 Mshowa
.02381 .2479 m
.03006 .2479 L
s
[(80)] .01131 .2479 1 0 Mshowa
.02381 .34945 m
.03006 .34945 L
s
[(100)] .01131 .34945 1 0 Mshowa
.02381 .451 m
.03006 .451 L
s
[(120)] .01131 .451 1 0 Mshowa
.02381 .55254 m
.03006 .55254 L
s
[(140)] .01131 .55254 1 0 Mshowa
.125 Mabswid
.02381 .07019 m
.02756 .07019 L
s
.02381 .09558 m
.02756 .09558 L
s
.02381 .12096 m
.02756 .12096 L
s
.02381 .17174 m
.02756 .17174 L
s
.02381 .19713 m
.02756 .19713 L
s
.02381 .22251 m
.02756 .22251 L
s
.02381 .27329 m
.02756 .27329 L
s
.02381 .29867 m
.02756 .29867 L
s
.02381 .32406 m
.02756 .32406 L
s
.02381 .37484 m
.02756 .37484 L
s
.02381 .40022 m
.02756 .40022 L
s
.02381 .42561 m
.02756 .42561 L
s
.02381 .47638 m
.02756 .47638 L
s
.02381 .50177 m
.02756 .50177 L
s
.02381 .52716 m
.02756 .52716 L
s
.02381 .01942 m
.02756 .01942 L
s
.02381 .57793 m
.02756 .57793 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .53234 L
.10458 .46417 L
.14415 .40788 L
.18221 .35998 L
.22272 .31492 L
.26171 .27666 L
.30316 .24083 L
.34309 .21046 L
.3815 .18463 L
.42237 .16038 L
.46172 .13981 L
.49955 .12229 L
.53984 .10579 L
.57861 .09177 L
.61984 .07863 L
.65954 .06749 L
.69774 .05801 L
.73838 .0491 L
.77751 .04154 L
.81909 .03446 L
.85916 .02846 L
.89771 .02336 L
.93871 .01858 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`0087oo00<007ooOol0ogooSWoo000POol0
0`00Oomoo`3oOon>Ool0021oo`03001oogoo031oo`03OoLh000000@00005>_moogooOomnkP030000
0c[oOomoo`02Ool01Gk^00000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`0SOol0
1Gmb80000000>_l00goo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l0
17oo00EnkP00000003[o029oo`05GL00000000iOo`03Ool01Gk^00000000>_l017oo00EnkP000000
03[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l08Goo00EM`0000000007G00Aoo`05O^h0
0000000jo`04Ool01Gk^00000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`0LOol0
0gk^0000000300001@7GOomoogooO^h00`0000<jogooOol00Woo00EnkP00000003[o00Aoo`05O^h0
0000000jo`04Ool01Gk^00000000>_l017oo00EnkP00000003[o00Aoo`0087oo00<007ooOol0<Goo
00=M`00>Gol00Woo00=^KT]oOol00Woo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06
B@iOogooOoLh3Uoo0goo00I93UooOomomcP>GolTOol00eg0>_moo`03Ool01TT>Gomoogog>0iOo`=o
o`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOob1oo`06KVP1egoo
OomnkP7G0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo
00I93UooOomomcP>GolOOol00gk^0MMoo`02Ool00eg8Bgmoo`02Ool01TT>Gomoogog>0iOo`=oo`06
B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOoaioo`03B@Q;Ogoo00Ao
o`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogoo
OoLh3Uoo0goo00I93UooOomomcP>Gol3Ool0021oo`03001oogoo039oo`03O^h024]o00Eoo`03O^h1
egoo009oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`03
KVPRNgoo02=oo`03GL0jogoo009oo`03O^h1egoo009oo`06KVPRNgooOomnkP7G0goo00I^J29kOomo
ogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`03KVPRNgoo01ioo`03OoLh03[o009oo`06OoLi4WooOomn
kP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00=^
J29kOol07Woo00=^J29kOol00Woo00IM`3[oOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPR
NgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`0MOol00dT8Bgmoo`03Ool00gk^0MMo
o`02Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX
8W]oogooO^h1e`=oo`03KVPRNgoo009oo`0087oo00<007ooOol0<goo00=oLR008W/017oo00=^J29k
Ool00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=n
kP7GOol07goo00=^J00000000`0000DjogooOom^J29k00=oo`06O^h1egooOom^J29k0goo00InkP7G
OomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo01ioo`07O^h123P>GomoofiX0ML00Woo
00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k
0goo00=nkP7GOol07Woo00=nkP4BOol00Woo00I924]oOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=o
o`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0MOol00dT8Bgmoo`03Ool0
0fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3
Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo009oo`0087oo00<007ooOol0=Goo00=9029kOol00Woo
00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k
0goo00=nkP7GOol07goo00InkP0>Gomooeg0>_l3Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=o
o`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0NOol00gmb8A9nkP020000
1P4BOomoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogoo
KVPRN`=oo`03O^h1egoo01moo`05KVP00000000RN`03Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPR
N`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0MOol00dT8Bgmoo`03
Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX
8W/3Ool400000fiX8W]oo`02Ool00gk^0MMoo`02Ool0021oo`03001oogoo03Ioo`06B@iOogooOom^
J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=n
kP7GOol087oo00E^J07GOomM`3[o00=oo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo00InkP7G
OomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo01ioo`03OoLh3Uoo00Ioo`03KVPRNgoo
009oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1
egoo01ioo`03OoLi4Woo009oo`06B@iOogooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMo
ogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol07Goo00=924]oOol00goo00=^J29kOol0
0Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h0000000H00006O^h1egooOom^
J29k0goo00=nkP7GOol00Woo000POol2000bOol00fiX>_moo`02Ool01Ug0>_moogooO^hRN`=oo`06
KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`03KVPRNgoo025o
o`04B@0RNeg0>_l3Ool00gk^8W]oo`02Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo
00I^J29kOomoogk^8W/3Ool00fiX8W]oo`0OOol00eg08W]oo`05Ool00gk^8W]oo`02Ool01ViX8W]o
ogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool00fiX8W]oo`0NOol00gk^
8W]oo`02Ool01Ug0>_moogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool0
1ViX8W]oogooO^hRN`=oo`03KVPRNgoo01eoo`03B@Q;Ogoo00=oo`03O^hRNgoo009oo`06KVPRNgoo
OomnkR9k0goo00=^J29k00001`0000DRNgooOomnkR9k00=oo`06KVPRNgooOomnkR9k0goo00=^J29k
Ool00Woo000POol00`00Oomoo`0aOol01gk^00iOogooO^h024]o00=oo`06B@0jogooOg8P3Uoo0goo
00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo8Woo00AoLR088@0j
o`Aoo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0j
ogooOg8P3Uoo87oo00=omcP00ML01Woo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06
B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>GolOOol01gmb80iOogooOg8P3Uoo00=oo`06B@0jogoo
Og8P3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo6goo
00E^J0000A9924]o00Eoo`07B@0jogooOg8P3UooOol020000goo00I903[oOomoLR0>Gol3Ool01TT0
>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo000POol00`00Oomoo`0bOol01Gk^00000008Bgl0
17oo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP00000
24]o02Aoo`03O^h003[o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP00000
24]o00Aoo`05OoLh000000Q;O`0SOol015g00000004B0goo00EomcP0000024]o00Aoo`05OoLh0000
00Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o025oo`05O^h0000000Q;O`04Ool01Gog
>0000008Bgl017oo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl07Woo
00=^J008Bgl017oo20000Woo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008
Bgl017oo00EomcP0000024]o00Aoo`0087oo00<007ooOol0ogooF7oo2000;Woo000POol00`00Oomo
o`3oOomAOol7000fOol0021oo`03001oogoo0?moodaoo`D003eoo`0087oo00<007ooOol0ogooAWoo
1P00@Woo000POol00`00Oomoo`3oOoloOol70018Ool0021oo`03001oogoo0?moocMoo`P004moo`00
87oo00<007ooOol0ogoo<Goo1P00Egoo000POol00`00Oomoo`3oOol]Ool4001MOol001Ioool009X0
005oo`0087oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<0
07ooOol047oo00<007ooOol03Woo100047oo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol03goo00<007ooOol027oo000POol00`00Oomoo`17Ool00`00Oomoo`17Ool00`00
Oomoo`17Ool00`00Oomoo`11Ool50002Ool00`00Oomoo`17Ool00`00Oomoo`0JOol0021oo`03001o
ogoo0?mooaYoo`H006ioo`0087oo00<007ooOol0ogoo57oo1P00M7oo000POol00`00Oomoo`3oOol@
Ool4001jOol0021oo`03001oogoo0?moo`aoo`@007ioo`0087oo00<007ooOol0ogoo27oo1000PWoo
000POol00`00Oomoo`3oOol4Ool40026Ool0021oo`03001oogoo0?moo`@008Yoo`0087oo0P00oGoo
0`00SWoo000POol00`00Oomoo`3iOol3002AOol0021oo`03001oogoo0?Eoo`@009Aoo`0087oo00<0
07ooOol0lWoo0`00V7oo000POol00`00Oomoo`3_Ool3002KOol0021oo`03001oogoo0>]oo`@009io
o`0087oo00<007ooOol0j7oo0`00XWoo000POol00`00Oomoo`3UOol3002UOol0021oo`03001oogoo
0>5oo`@00:Qoo`0087oo00<007ooOol0gWoo0`00[7oo000POol2003MOol2002_Ool0021oo`03001o
ogoo0=Uoo`<00;5oo`0087oo00<007ooOol0eWoo0`00]7oo000POol00`00Oomoo`3DOol2002gOol0
021oo`03001oogoo0=5oo`<00;Uoo`0087oo00<007ooOol0cWoo0`00_7oo000POol00`00Oomoo`3<
Ool2002oOol0021oo`03001oogoo0<Uoo`<00<5oo`0087oo00<007ooOol0aWoo0`00a7oo000POol0
0`00Oomoo`34Ool20037Ool0021oo`03001oogoo0<5oo`<00<Uoo`0087oo0P00`7oo0P00c7oo000P
Ool00`00Oomoo`2mOol2003>Ool0021oo`03001oogoo0;]oo`800=1oo`0087oo00<007ooOol0^Goo
0P00dWoo000POol00`00Oomoo`2gOol2003DOol0021oo`03001oogoo0;Eoo`800=Ioo`0087oo00<0
07ooOol0/goo0P00f7oo000<Ool01Eg00000000>Gol00goo00EnkP00000003[o00Moo`03001oogoo
0;5oo`800=Yoo`002goo00I^J07GOomoogk^0ML3Ool01TT>Gomoogog>0iOo`Ioo`03001oogoo0:mo
o`800=aoo`002Woo00=omcP0>_l00Woo00IomcTBOomoogk^0ML3Ool00fiX8W]oo`05Ool00`00Oomo
o`2]Ool2003NOol000Yoo`07O^h123P>GomoofiX0ML00Woo00=^J29kOol00Woo00=nkP7GOol01Goo
0`00Zgoo0P00h7oo000:Ool00gmb8A9nkP0200001P4BOomoogooKVPRN`=oo`03O^h1egoo00Eoo`03
001oogoo0:Uoo`800>9oo`002Woo00=omcP>Gol01Woo00=^J29kOol00Woo00=nkP7GOol01Goo00<0
07ooOol0Ygoo0P00i7oo000;Ool00eg08W]oo`05Ool00gk^8W]oo`02Ool00fiX8W]oo`05Ool00`00
Oomoo`2UOol2003VOol000]oo`03OoLh007G00Ioo`06B@0jogooOg8P3Uoo1Woo00<007ooOol0Xgoo
0P00j7oo000=Ool015g00000004B0goo00EomcP0000024]o00Moo`03001oogoo0:5oo`800>Yoo`00
87oo00<007ooOol0Wgoo0P00k7oo000POol00`00Oomoo`2MOol2003^Ool0021oo`03001oogoo09ao
o`03001oogoo0>ioo`0087oo00<007ooOol0VWoo0P00lGoo000POol00`00Oomoo`2HOol2003cOol0
021oo`8009Qoo`03001oogoo0?=oo`0087oo00<007ooOol0UGoo0P00mWoo000POol00`00Oomoo`2D
Ool00`00Oomoo`3fOol0021oo`03001oogoo099oo`800?Uoo`0087oo00<007ooOol0T7oo0P00ngoo
000POol00`00Oomoo`2?Ool00`00Oomoo`3kOol0021oo`03001oogoo08eoo`800?ioo`0087oo00<0
07ooOol0S7oo00<007ooOol0oWoo000POol00`00Oomoo`2:Ool2003oOol2Ool0021oo`03001oogoo
08Qoo`800?moo`Aoo`0087oo0P00R7oo00<007ooOol0ogoo17oo000POol00`00Oomoo`25Ool2003o
Ool7Ool0021oo`03001oogoo08Aoo`03001oogoo0?moo`Moo`0087oo00<007ooOol0PWoo0P00ogoo
2Woo000POol00`00Oomoo`20Ool2003oOol<Ool0021oo`03001oogoo07moo`03001oogoo0?moo`ao
o`0087oo00<007ooOol0OWoo00<007ooOol0ogoo3Goo000POol00`00Oomoo`1lOol2003oOol@Ool0
021oo`03001oogoo07]oo`03001oogoo0?mooa1oo`0087oo00<007ooOol0NWoo00<007ooOol0ogoo
4Goo000POol2001jOol00`00Oomoo`3oOolBOol0021oo`03001oogoo07Qoo`03001oogoo0?mooa=o
o`0087oo00<007ooOol0MWoo0P00ogoo5Woo000POol00`00Oomoo`1eOol00`00Oomoo`3oOolFOol0
021oo`03001oogoo07Aoo`03001oogoo0?mooaMoo`0087oo00<007ooOol0Lgoo00<007ooOol0ogoo
67oo000POol00`00Oomoo`1aOol2003oOolKOol000]oo`05GL0000000001e`04Ool01Gk^00000000
>_l01goo00<007ooOol0L7oo00<007ooOol0ogoo6goo000:Ool00gk^0MMoo`02Ool00eg8Bgmoo`02
Ool01TT>Gomoogog>0iOo`Ioo`03001oogoo06moo`03001oogoo0?mooaaoo`002Woo00=^J29kOol0
0Woo00IM`3[oOomoogk^0ML3Ool00fiX8W]oo`05Ool00`00Oomoo`1^Ool00`00Oomoo`3oOolMOol0
00Yoo`03O^h14Woo009oo`06B@Q;OgooOom^J29k0goo00=nkP7GOol01Goo00<007ooOol0K7oo0P00
ogoo87oo000;Ool01FiX000000008W/00goo00=^J29kOol00Woo00=nkP7GOol01Goo0`00Jgoo00<0
07ooOol0ogoo87oo000:Ool00gog>A9oo`02Ool01TT>GomoogooKVPRN`=oo`03O^h1egoo00Eoo`03
001oogoo06Yoo`03001oogoo0?moob5oo`002Woo00=nkR9kOol00Woo00IM`3[oOomoogk^8W/3Ool0
0fiX8W]oo`05Ool00`00Oomoo`1YOol00`00Oomoo`3oOolROol000Yoo`07Og8P3UooOomoLR0>Gol0
0goo00I903[oOomoLR0>Gol6Ool00`00Oomoo`1XOol00`00Oomoo`3oOolSOol000]oo`05O^h00000
00Q;O`04Ool01Gog>0000008Bgl01goo00<007ooOol0IWoo0P00ogoo9Woo000POol00`00Oomoo`1U
Ool00`00Oomoo`3oOolVOol0021oo`03001oogoo06Aoo`03001oogoo0?moobMoo`0087oo00<007oo
Ool0Hgoo00<007ooOol0ogoo:7oo000POol00`00Oomoo`1ROol00`00Oomoo`3oOolYOol0021oo`03
001oogoo061oo`800?moobaoo`0087oo0P00H7oo00<007ooOol0ogoo;7oo000POol00`00Oomoo`1N
Ool00`00Oomoo`3oOol]Ool0021oo`03001oogoo05eoo`03001oogoo0?moobioo`0087oo00<007oo
Ool0G7oo00<007ooOol0ogoo;goo000POol00`00Oomoo`1KOol00`00Oomoo`3oOol`Ool0021oo`03
001oogoo05Yoo`03001oogoo0?mooc5oo`0087oo00<007ooOol0FGoo00<007ooOol0ogoo<Woo000P
Ool00`00Oomoo`1HOol00`00Oomoo`3oOolcOol0021oo`03001oogoo05Moo`03001oogoo0?moocAo
o`0087oo00<007ooOol0EWoo00<007ooOol0ogoo=Goo000POol2001FOol00`00Oomoo`3oOolfOol0
021oo`03001oogoo05Aoo`03001oogoo0?moocMoo`0087oo00<007ooOol0Dgoo00<007ooOol0ogoo
>7oo000POol00`00Oomoo`1BOol00`00Oomoo`3oOoliOol0021oo`03001oogoo055oo`03001oogoo
0?moocYoo`0087oo00<007ooOol0D7oo00<007ooOol0ogoo>goo000POol00`00Oomoo`1?Ool00`00
Oomoo`3oOollOol0021oo`03001oogoo04ioo`03001oogoo0?mooceoo`0087oo00<007ooOol0CGoo
00<007ooOol0ogoo?Woo000POol00`00Oomoo`1<Ool00`00Oomoo`3oOoloOol0021oo`03001oogoo
04]oo`03001oogoo0?mood1oo`0087oo0P00Bgoo00<007ooOol0ogoo@Goo000POol00`00Oomoo`1:
Ool00`00Oomoo`3oOom1Ool0021oo`03001oogoo04Uoo`03001oogoo0?mood9oo`0087oo00<007oo
Ool0B7oo00<007ooOol0ogoo@goo000POol00`00Oomoo`17Ool00`00Oomoo`3oOom4Ool0021oo`03
001oogoo04Ioo`03001oogoo0?moodEoo`0087oo00<007ooOol0AGoo00<007ooOol0ogooAWoo0000
0gooO^h0000400001@7GOomoogooO^h00`0000<jogooOol00Woo00EnkP00000003[o00Moo`03001o
ogoo04Aoo`03001oogoo0?moodMoo`0017oo00=924]oOol017oo00I93UooOomomcP>Gol3Ool01TT>
Gomoogog>0iOo`Ioo`03001oogoo04=oo`03001oogoo0?moodQoo`0017oo00=924]oOol00goo00=n
kP7GOol00Woo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`05Ool00`00Oomoo`12Ool00`00Oomoo`3o
Oom9Ool000Aoo`03B@Q;Ogoo00=oo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo00=nkP7GOol0
1Goo0`00@Goo00<007ooOol0ogooBWoo0004Ool00dT8Bgmoo`03Ool00fiX8W]oo`02Ool01Wk^0MMo
ogooKVPRN`=oo`03O^h1egoo00Eoo`03001oogoo045oo`03001oogoo0?moodYoo`0017oo00=924]o
Ool00goo00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`05Ool00`00Oomoo`10Ool0
0`00Oomoo`3oOom;Ool000Aoo`03B@Q;Ogoo00=oo`03O^hRNgoo009oo`06KVPRNgooOomnkR9k0goo
00=^J29kOol01Goo00<007ooOol0?goo00<007ooOol0ogooC7oo00001WooKVP0004BB@Q;O`Eoo`06
B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol6Ool00`00Oomoo`0nOol00`00Oomoo`3oOom=Ool0
00=oo`03KVP024]o00Eoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl01goo00<007ooOol0?Goo
00<007ooOol0ogooCWoo000POol00`00Oomoo`0lOol00`00Oomoo`3oOom?Ool0021oo`03001oogoo
03]oo`03001oogoo0?mooe1oo`0087oo00<007ooOol0>goo00<007ooOol0ogooD7oo000POol00`00
Oomoo`0jOol00`00Oomoo`3oOomAOol0021oo`03001oogoo03Uoo`03001oogoo0?mooe9oo`0087oo
0P00>Goo00<007ooOol0ogooDgoo000POol00`00Oomoo`0gOol00`00Oomoo`3oOomDOol0021oo`03
001oogoo03Moo`03001oogoo0?mooeAoo`0087oo00<007ooOol0=Woo00<007ooOol0ogooEGoo000P
Ool00`00Oomoo`0eOol00`00Oomoo`3oOomFOol0021oo`03001oogoo03Aoo`03001oogoo0?mooeMo
o`0087oo00<007ooOol0=7oo00<007ooOol0ogooEgoo000POol00`00Oomoo`0cOol00`00Oomoo`3o
OomHOol0021oo`03001oogoo039oo`03001oogoo0?mooeUoo`0087oo00<007ooOol0<Goo00<007oo
Ool0ogooFWoo000POol2000aOol00`00Oomoo`3oOomKOol0021oo`03001oogoo031oo`03001oogoo
0?mooe]oo`0087oo00<007ooOol0;goo00<007ooOol0ogooG7oo000POol00`00Oomoo`0^Ool00`00
Oomoo`3oOomMOol0021oo`03001oogoo02eoo`03001oogoo0?mooeioo`0087oo00<007ooOol0;Goo
00<007ooOol0ogooGWoo000POol00`00Oomoo`0/Ool00`00Oomoo`3oOomOOol0021oo`03001oogoo
02]oo`03001oogoo0?moof1oo`0087oo00<007ooOol0:goo00<007ooOol0ogooH7oo000POol00`00
Oomoo`0ZOol00`00Oomoo`3oOomQOol0021oo`8002Yoo`03001oogoo0?moof9oo`0087oo00<007oo
Ool0:7oo00<007ooOol0ogooHgoo000POol00`00Oomoo`0XOol00`00Oomoo`3oOomSOol0021oo`03
001oogoo02Moo`03001oogoo0?moofAoo`0087oo00<007ooOol09Woo00<007ooOol0ogooIGoo000P
Ool00`00Oomoo`0VOol00`00Oomoo`3oOomUOol0021oo`03001oogoo02Eoo`03001oogoo0?moofIo
o`0000=oogk^0000100000@1egooOoLh00D00005>_moogooOomnkP0300000c[oOomoo`05Ool00`00
Oomoo`0TOol00`00Oomoo`3oOomWOol000Aoo`03B@Q;Ogoo00=oo`03GL003Uoo009oo`03KVi;Ogoo
009oo`06B@iOogooOoLh3Uoo1Woo00<007ooOol097oo00<007ooOol0ogooIgoo0004Ool00dT8Bgmo
o`04Ool00gk^00Q;O`05Ool00gk^0MMoo`02Ool00fiX8W]oo`05Ool00`00Oomoo`0SOol00`00Oomo
o`3oOomXOol000Aoo`03B@Q;Ogoo00Eoo`03Og8P029k00Aoo`03KVPRNgoo009oo`03O^h1egoo00Eo
o`03001oogoo029oo`03001oogoo0?moofUoo`0017oo00=924]oOol01goo00=9029kOol00Woo00=^
J29kOol00Woo00=nkP7GOol01Goo0`008Goo00<007ooOol0ogooJWoo0004Ool00dT8Bgmoo`08Ool0
1TT>GomoogooKVPRN`=oo`03O^h1egoo00Eoo`03001oogoo025oo`03001oogoo0?moofYoo`0017oo
00=924]oOol00goo00=^J3[oOol00Woo00IM`3[oOomoogk^8W/3Ool00fiX8W]oo`05Ool00`00Oomo
o`0POol00`00Oomoo`3oOom[Ool00006Oom^J0000A9924]o17oo00MnkP0>Gomoogk^00Q;O`03Ool0
1TT0>_moogmb80iOo`Ioo`03001oogoo01moo`03001oogoo0?moofaoo`000goo00=^J008Bgl01Goo
00EnkP00000024]o00Aoo`05OoLh000000Q;O`07Ool00`00Oomoo`0OOol00`00Oomoo`3oOom/Ool0
021oo`03001oogoo01ioo`03001oogoo0?moofeoo`0087oo00<007ooOol07Goo00<007ooOol0ogoo
KWoo000POol00`00Oomoo`0MOol00`00Oomoo`3oOom^Ool0021oo`03001oogoo01aoo`03001oogoo
0?moofmoo`0087oo00<007ooOol06goo00<007ooOol0ogooL7oo000POol2000LOol00`00Oomoo`3o
Oom`Ool0021oo`03001oogoo01Yoo`03001oogoo0?moog5oo`0087oo00<007ooOol06Goo00<007oo
Ool0ogooLWoo000POol00`00Oomoo`0IOol00`00Oomoo`3oOombOol0021oo`03001oogoo01Qoo`03
001oogoo0?moog=oo`0087oo00<007ooOol067oo00<007ooOol0ogooLgoo000POol00`00Oomoo`0G
Ool00`00Oomoo`3oOomdOol0021oo`03001oogoo01Ioo`03001oogoo0?moogEoo`0087oo00<007oo
Ool05Woo00<007ooOol0ogooMGoo000POol00`00Oomoo`0EOol00`00Oomoo`3oOomfOol0021oo`80
01Eoo`03001oogoo0?moogMoo`0087oo00<007ooOol057oo00<007ooOol0ogooMgoo000POol00`00
Oomoo`0COol00`00Oomoo`3oOomhOol0021oo`03001oogoo019oo`03001oogoo0?moogUoo`0087oo
00<007ooOol04Woo00<007ooOol0ogooNGoo000POol00`00Oomoo`0AOol00`00Oomoo`3oOomjOol0
021oo`03001oogoo011oo`03001oogoo0?moog]oo`0087oo00<007ooOol047oo00<007ooOol0ogoo
Ngoo000POol00`00Oomoo`0?Ool00`00Oomoo`3oOomlOol0021oo`03001oogoo00moo`03001oogoo
0?moogaoo`0087oo00<007ooOol03Woo00<007ooOol0ogooOGoo000POol2000>Ool00`00Oomoo`3o
OomnOol0021oo`03001oogoo00eoo`03001oogoo0?moogioo`0087oo00<007ooOol037oo00<007oo
Ool0ogooOgoo000POol00`00Oomoo`0;Ool00`00Oomoo`3oOon0Ool0021oo`03001oogoo00]oo`03
001oogoo0?mooh1oo`0087oo00<007ooOol02Woo00<007ooOol0ogooPGoo000POol00`00Oomoo`0:
Ool00`00Oomoo`3oOon1Ool00003OomnkP0000@000030MMoogoo009oo`05Og8P0000000jo`03Ool0
1Gk^00000000>_l01goo00<007ooOol02Goo00<007ooOol0ogooPWoo0004Ool00dT8Bgmoo`07Ool0
0eg0>_moo`03Ool01TT>Gomoogog>0iOo`Ioo`03001oogoo00Uoo`03001oogoo0?mooh9oo`0017oo
00=924]oOol01goo00=M`3[oOol00Woo00=nkP7GOol00Woo00=^J29kOol01Goo00<007ooOol027oo
00<007ooOol0ogooPgoo0004Ool00dT8Bgmoo`03Ool00fiX0000000300001C[oOomoofiX8W/00goo
00=nkP7GOol01Goo0`0027oo00<007ooOol0ogooPgoo0004Ool00dT8Bgmoo`03Ool01Wk^00iOogoo
GL0jo`=oo`03KVPRNgoo009oo`03O^h1egoo00Eoo`03001oogoo00Moo`03001oogoo0?moohAoo`00
17oo00=924]oOol017oo00E^J07GOomM`3[o00=oo`03KVPRNgoo009oo`03O^h1egoo00Eoo`03001o
ogoo00Moo`03001oogoo0?moohAoo`0017oo00=924]oOol01Goo00A9029kGL0jo`=oo`03O^hRNgoo
009oo`03KVPRNgoo00Eoo`03001oogoo00Ioo`03001oogoo0?moohEoo`0000IoofiX00014TT8Bgl6
Ool017mb80PQ03[o17oo00I903[oOomoLR0>Gol6Ool00`00Oomoo`06Ool00`00Oomoo`3oOon5Ool0
00=oo`03KVP024]o00Moo`03O^h003[o00Aoo`05OoLh000000Q;O`07Ool00`00Oomoo`05Ool00`00
Oomoo`3oOon6Ool0021oo`03001oogoo00Eoo`03001oogoo0?moohIoo`0087oo00<007ooOol017oo
00<007ooOol0ogooQgoo000POol00`00Oomoo`04Ool00`00Oomoo`3oOon7Ool0021oo`03001oogoo
00=oo`03001oogoo0?moohQoo`0087oo00<007ooOol00goo00<007ooOol0ogooR7oo000POol20003
Ool00`00Oomoo`3oOon9Ool0021oo`03001oogoo009oo`03001oogoo0?moohUoo`0087oo00D007oo
Oomoo`000?moohaoo`0087oo00D007ooOomoo`000?moohaoo`0087oo00@007ooOol00?mooheoo`00
87oo00@007ooOol00?mooheoo`0087oo00<007oo0000ogooSWoo000POol00`00Ool0003oOon>Ool0
021oo`800?moohmoo`0087oo0P00ogooSgoo000POol2003oOon?Ool0021oo`03001oogoo0?moohio
o`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohio
o`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool00?mook5oo`00ogoo/Goo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8651.93, 27.889, 404.176, \
0.72299}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g[t], {t, 0, 10\ 3600}, 
        PlotRange \[Rule] {All, {25, 150}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 2.6455e-005 -0.123607 0.00494427 [
[.15608 .06166 -12 -9 ]
[.15608 .06166 12 0 ]
[.28836 .06166 -15 -9 ]
[.28836 .06166 15 0 ]
[.42063 .06166 -15 -9 ]
[.42063 .06166 15 0 ]
[.55291 .06166 -15 -9 ]
[.55291 .06166 15 0 ]
[.68519 .06166 -15 -9 ]
[.68519 .06166 15 0 ]
[.81746 .06166 -15 -9 ]
[.81746 .06166 15 0 ]
[.94974 .06166 -15 -9 ]
[.94974 .06166 15 0 ]
[.01131 .17305 -12 -4.5 ]
[.01131 .17305 0 4.5 ]
[.01131 .27193 -12 -4.5 ]
[.01131 .27193 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .46971 -18 -4.5 ]
[.01131 .46971 0 4.5 ]
[.01131 .56859 -18 -4.5 ]
[.01131 .56859 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15608 .07416 m
.15608 .08041 L
s
[(5000)] .15608 .06166 0 1 Mshowa
.28836 .07416 m
.28836 .08041 L
s
[(10000)] .28836 .06166 0 1 Mshowa
.42063 .07416 m
.42063 .08041 L
s
[(15000)] .42063 .06166 0 1 Mshowa
.55291 .07416 m
.55291 .08041 L
s
[(20000)] .55291 .06166 0 1 Mshowa
.68519 .07416 m
.68519 .08041 L
s
[(25000)] .68519 .06166 0 1 Mshowa
.81746 .07416 m
.81746 .08041 L
s
[(30000)] .81746 .06166 0 1 Mshowa
.94974 .07416 m
.94974 .08041 L
s
[(35000)] .94974 .06166 0 1 Mshowa
.125 Mabswid
.05026 .07416 m
.05026 .07791 L
s
.07672 .07416 m
.07672 .07791 L
s
.10317 .07416 m
.10317 .07791 L
s
.12963 .07416 m
.12963 .07791 L
s
.18254 .07416 m
.18254 .07791 L
s
.20899 .07416 m
.20899 .07791 L
s
.23545 .07416 m
.23545 .07791 L
s
.2619 .07416 m
.2619 .07791 L
s
.31481 .07416 m
.31481 .07791 L
s
.34127 .07416 m
.34127 .07791 L
s
.36772 .07416 m
.36772 .07791 L
s
.39418 .07416 m
.39418 .07791 L
s
.44709 .07416 m
.44709 .07791 L
s
.47354 .07416 m
.47354 .07791 L
s
.5 .07416 m
.5 .07791 L
s
.52646 .07416 m
.52646 .07791 L
s
.57937 .07416 m
.57937 .07791 L
s
.60582 .07416 m
.60582 .07791 L
s
.63228 .07416 m
.63228 .07791 L
s
.65873 .07416 m
.65873 .07791 L
s
.71164 .07416 m
.71164 .07791 L
s
.7381 .07416 m
.7381 .07791 L
s
.76455 .07416 m
.76455 .07791 L
s
.79101 .07416 m
.79101 .07791 L
s
.84392 .07416 m
.84392 .07791 L
s
.87037 .07416 m
.87037 .07791 L
s
.89683 .07416 m
.89683 .07791 L
s
.92328 .07416 m
.92328 .07791 L
s
.97619 .07416 m
.97619 .07791 L
s
.25 Mabswid
0 .07416 m
1 .07416 L
s
.02381 .17305 m
.03006 .17305 L
s
[(60)] .01131 .17305 1 0 Mshowa
.02381 .27193 m
.03006 .27193 L
s
[(80)] .01131 .27193 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(100)] .01131 .37082 1 0 Mshowa
.02381 .46971 m
.03006 .46971 L
s
[(120)] .01131 .46971 1 0 Mshowa
.02381 .56859 m
.03006 .56859 L
s
[(140)] .01131 .56859 1 0 Mshowa
.125 Mabswid
.02381 .09889 m
.02756 .09889 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14833 m
.02756 .14833 L
s
.02381 .19777 m
.02756 .19777 L
s
.02381 .22249 m
.02756 .22249 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .29666 m
.02756 .29666 L
s
.02381 .32138 m
.02756 .32138 L
s
.02381 .3461 m
.02756 .3461 L
s
.02381 .39554 m
.02756 .39554 L
s
.02381 .42026 m
.02756 .42026 L
s
.02381 .44498 m
.02756 .44498 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51915 m
.02756 .51915 L
s
.02381 .54387 m
.02756 .54387 L
s
.02381 .04944 m
.02756 .04944 L
s
.02381 .02472 m
.02756 .02472 L
s
.02381 .59331 m
.02756 .59331 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.06244 .59335 L
.10458 .56758 L
.14415 .54442 L
.18221 .52307 L
.22272 .50129 L
.26171 .4812 L
.30316 .46076 L
.34309 .44191 L
.3815 .42453 L
.42237 .40682 L
.46172 .39049 L
.49955 .37543 L
.53984 .36006 L
.57861 .34588 L
.61984 .33145 L
.65954 .31814 L
.69774 .30586 L
.73838 .29335 L
.77751 .28181 L
.81909 .27007 L
.85916 .25925 L
.89771 .24927 L
.93871 .2391 L
.97619 .23019 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo000POol00`00Oomoo`3oOon>
Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>
Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>
Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>
Ool0021oo`800?moohmoo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021o
o`03001oogoo029oo`05GL000000000jo`04Ool01Gk^00000000>_l017oo00EnkP00000003[o00Ao
o`05O^h00000000jo`0AOol00gk^0000000300001@7GOomoogooO^h00`0000<jogooOol00Woo00En
kP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l02goo00=nkP0000000`0000D1
egooOomooeg000<00003>_moogoo009oo`05O^h00000000jo`04Ool01Gk^00000000>_l017oo00En
kP00000003[o00]oo`03OoLh000000@00005>_moogooOomnkP0300000c[oOomoo`02Ool01Gk^0000
0000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`0;Ool00gog>000000400001C[oOomo
ogooGL000`0000<jogooOol00Woo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^0000
0000>_l03Goo00EM`0000000029k00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l017oo00En
kP00000003[o00Aoo`05O^h00000000jo`0=Ool01Eg0000000008W/017oo00EM`000000003[o00Ao
o`05O^h00000000jo`04Ool01Gk^00000000>_l017oo00EnkP00000003[o00=oo`0087oo00<007oo
Ool08Goo00MM`07GOomoogmb800jo`03Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo
00I93UooOomomcP>GolCOol00dT8Bgmoo`04Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo
0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`eoo`03B@Q;Ogoo00=oo`07GL01egooOomo
LR00>_l00goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo2goo
00=M`00>Gol00Woo00=^KT]oOol00Woo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06
B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol;Ool00eg000iOo`02Ool01Vi^BgmoogooGL01e`9o
o`03Og8P03[o00=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iO
o`]oo`07GL01egooOomomcP08W/00goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06
B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol;Ool01eg00MMoogooOoLh029k009oo`07GL01egoo
OomoLR00>_l00goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo
0Woo000POol00`00Oomoo`0VOol01Wk^0MMoogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29k
Oomoogk^0ML3Ool00fiX8W]oo`0BOol00dT8Bgmoo`03Ool00gk^0MMoo`02Ool01ViX8W]oogooO^h1
e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`0<Ool00dT8Bgmoo`08
Ool01Wk^0MMoogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]o
o`0;Ool00gk^00Q;O`05Ool00gk^0MMoo`02Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G
0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`0;Ool00gk^00Q;O`0:Ool01Wk^0MMoogooO^h1e`=o
o`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`0?Ool01Wk^0MMoogooO^h1
e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`03KVPR
Ngoo00moo`03O^h1egoo00Ioo`06O^h1egooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]o
ogooO^h1e`=oo`03KVPRNgoo005oo`0087oo00<007ooOol09Woo00InkP7GOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol04Woo00=924]oOol00goo00=^J29k
Ool00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=n
kP7GOol037oo00=924]oOol027oo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1
egooOom^J29k0goo00=nkP7GOol037oo00=oLR008W/017oo00=^J29kOol00Woo00InkP7GOomoofiX
8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol037oo00=oLR008W/0
2Goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7G
Ool03Woo00=oLR08Bgl00Woo00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPR
N`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol03Woo00=oLR08Bgl01goo00InkP7GOomoofiX8W/3
Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol00Goo000POol00`00Oomo
o`0VOol01TT0>_moogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^
0MMoo`0BOol00dT8Bgmoo`03Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^
J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0<Ool00dT8Bgmoo`08Ool01TT0>_moogooKVPR
N`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0>Ool00dT08W]oo`02
Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX
8W/3Ool00gk^0MMoo`0>Ool00dT08W]oo`07Ool01TT0>_moogooKVPRN`=oo`06O^h1egooOom^J29k
0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0<Ool016iX000024]o0goo00=^J29kOol00Woo00In
kP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol037oo
00A^J00000Q;O`Qoo`06B@0jogooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPR
N`=oo`03O^h1egoo005oo`0087oo00<007ooOol08Goo00=omcP000000P0000HRNgooOomoofiX8W/3
Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol04Woo00=924]oOol00goo
00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k
0goo00=nkP7GOol037oo00=924]oOol00goo00=omcP000000P0000HRNgooOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol03goo00I93UooOomoofiX8W/3Ool0
1Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0?
Ool01TT>GomoogooOoLh00<000068W]oogooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMo
ogooKVPRN`=oo`03O^h1egoo00ioo`03Og8P24]o009oo`03KVPRNgoo009oo`06O^h1egooOom^J29k
0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo00ioo`03Og8P24]o009o
o`03OoLh0000008000068W]oogooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPR
N`=oo`03O^h1egoo005oo`0087oo00<007ooOol08Goo00=omcP>Gol01Woo00=nkR9kOol00Woo00I^
J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`03KVPRNgoo019oo`03B@Q;Ogoo00=oo`03O^hR
Ngoo009oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`03
KVPRNgoo00aoo`03B@Q;Ogoo00=oo`03OoLh3Uoo00Ioo`03O^hRNgoo009oo`06KVPRNgooOomnkR9k
0goo00I^J29kOomoogk^8W/3Ool00fiX8W]oo`0:Ool00fiX>_moo`02Ool01Ug0>_moogooO^hRN`=o
o`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`03KVPRNgoo
00Yoo`03KVPjogoo009oo`07GL0jogooOomomcP>Gol01Woo00=nkR9kOol00Woo00I^J29kOomoogk^
8W/3Ool01ViX8W]oogooO^hRN`=oo`03KVPRNgoo00moo`06GL0jogooOomnkR9k0goo00I^J29kOomo
ogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00=^J29kOol03goo00MM`3[o
Oomoogog>0iOo`06Ool00gk^8W]oo`02Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo
00=^J29kOol00Goo000POol2000ROol00gog>0iOo`07Ool01TT0>_moogmb80iOo`=oo`06B@0jogoo
Og8P3Uoo0goo00I903[oOomoLR0>Gol@Ool01FiX00014TT8Bgl01Goo00I903[oOomoLR0>Gol3Ool0
1TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol:Ool01FiX00014TT8
Bgl017oo00=omcP>Gol01goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogoo
Og8P3Uoo2goo00MnkP0>Gomoogk^00Q;O`03Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo
0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`]oo`07O^h03UooOomnkP08Bgl00Woo00=o
mcP>Gol01goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo2goo
00MnkP08Bgmoogmb80Q;O`03Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[o
OomoLR0>Gol3Ool01TT0>_moogmb80iOo`]oo`07O^h024]oOomoLR08Bgl00Woo00=omcP>Gol01goo
00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0Woo000POol00`00
Oomoo`0QOol00gog>000000200000`0>Gomoo`02Ool01Gog>0000008Bgl017oo00EomcP0000024]o
00Aoo`05OoLh000000Q;O`0COol00fiX00Q;O`05Ool01Gog>0000008Bgl017oo00EomcP0000024]o
00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl03Goo00=^J008Bgl017oo00=omcP000000P00
00<03UooOol00Woo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl03Goo
00EnkP00000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o
00Aoo`05OoLh000000Q;O`0=Ool01Gk^00000008Bgl00goo00=omcP000000P0000<03UooOol00Woo
00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl03Goo00EoLR00000003[o
00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o00Aoo`05OoLh0000
00Q;O`0=Ool01Gmb80000000>_l00goo00=omcP000000P0000<03UooOol00Woo00EomcP0000024]o
00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl00goo000POol00`00Oomoo`3oOon>Ool0021o
o`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021o
o`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021o
o`03001oogoo0?moohioo`005Wooo`00V0000goo000POol00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool0
021oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Qoo`03001oogoo00Qoo`03001oogoo00Yoo`0087oo00<007ooOol0<Woo00<007ooOol0<goo00<0
07ooOol0<goo00<007ooOol0<goo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol0<goo00<0
07ooOol05Goo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007oo
Ool0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007oo
Ool0ogooSWoo000POol2003oOon?Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogoo
SWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogoo
SWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogoo
SWoo000POol00`00Oomoo`3oOon>Ool0021oo`800?moohmoo`0087oo00<007ooOol0ogooSWoo000P
Ool00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000P
Ool00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000P
Ool00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo0P00ogooSgoo000POol00`00
Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00
Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000<Ool01Eg0
0000000>Gol00goo00EnkP00000003[o00Moo`03001oogoo0?moohioo`002goo00I^J07GOomoogk^
0ML3Ool01TT>Gomoogog>0iOo`Ioo`03001oogoo0?moohioo`002Woo00=omcP0>_l00Woo00IomcTB
Oomoogk^0ML3Ool00fiX8W]oo`05Ool00`00Oomoo`3oOon>Ool000Yoo`07O^h123P>GomoofiX0ML0
0Woo00=^J29kOol00Woo00=nkP7GOol01Goo0`00ogooSWoo000:Ool00gmb8A9nkP0200001P4BOomo
ogooKVPRN`=oo`03O^h1egoo00Eoo`03001oogoo0?moohioo`002Woo00=omcP>Gol01Woo00=^J29k
Ool00Woo00=nkP7GOol01Goo00<007ooOol0ogooSWoo000;Ool00eg08W]oo`05Ool00gk^8W]oo`02
Ool00fiX8W]oo`05Ool00`00Oomoo`3oOon>Ool000]oo`03OoLh007G00Ioo`06B@0jogooOg8P3Uoo
1Woo00<007ooOol0ogooSWoo000=Ool015g00000004B0goo00EomcP0000024]o00Moo`03001oogoo
0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo
0?moohioo`0087oo00<007ooOol0ogooSWoo000POol2003oOon?Ool0021oo`03001oogoo0?moohio
o`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohio
o`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohio
o`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`800?moohmoo`0087oo
00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo
00<007ooOol0ogooOgoo0`0037oo000POol00`00Oomoo`3oOomjOol5000?Ool0021oo`03001oogoo
0?moogEoo`D001Aoo`0087oo00<007ooOol0ogooL7oo1@006Goo000POol00`00Oomoo`3oOom/Ool4
000NOol0021oo`03001oogoo0?moofQoo`@0029oo`0087oo0P00ogooIGoo10009Woo000POol00`00
Oomoo`3oOomPOol4000ZOol0021oo`03001oogoo0?mooeaoo`@002ioo`0087oo00<007ooOol0ogoo
F7oo1000<Woo000POol00`00Oomoo`3oOomDOol4000fOol0021oo`03001oogoo0?mooe1oo`@003Yo
o`0087oo00<007ooOol0ogooCGoo0`00?Woo000;Ool01Eg0000000000ML017oo00EnkP00000003[o
00Moo`03001oogoo0?moodYoo`<0045oo`002Woo00=nkP7GOol00Woo00=Mb4]oOol00Woo00I93Uoo
OomomcP>Gol6Ool00`00Oomoo`3oOom6Ool40014Ool000Yoo`03KVPRNgoo009oo`06GL0jogooOomn
kP7G0goo00=^J29kOol01Goo00<007ooOol0ogoo@goo0`00B7oo000:Ool00gk^0A9oo`02Ool01TT8
BgmoogooKVPRN`=oo`03O^h1egoo00Eoo`<00?mood1oo`<004]oo`002goo00E^J0000000029k00=o
o`03KVPRNgoo009oo`03O^h1egoo00Eoo`03001oogoo0?moocaoo`@004ioo`002Woo00=omcTBOol0
0Woo00I93UooOomoofiX8W/3Ool00gk^0MMoo`05Ool00`00Oomoo`3oOoliOol3001BOol000Yoo`03
O^hRNgoo009oo`06GL0jogooOomnkR9k0goo00=^J29kOol01Goo00<007ooOol0ogoo=Woo0`00EGoo
000:Ool01gmb80iOogooOg8P3Uoo00=oo`06B@0jogooOg8P3Uoo1Woo00<007ooOol0ogoo<Woo1000
F7oo000;Ool01Gk^00000008Bgl017oo00EomcP0000024]o00Moo`03001oogoo0?moobmoo`<005ao
o`0087oo00<007ooOol0ogoo:goo1000Ggoo000POol00`00Oomoo`3oOolWOol4001SOol0021oo`03
001oogoo0?moob=oo`@006Moo`0087oo00<007ooOol0ogoo7goo1000Jgoo000POol00`00Oomoo`3o
OolLOol3001_Ool0021oo`800?mooaYoo`<0079oo`0087oo00<007ooOol0ogoo5Goo1000MGoo000P
Ool00`00Oomoo`3oOolBOol3001iOol0021oo`03001oogoo0?moo`moo`<007aoo`0087oo00<007oo
Ool0ogoo37oo0`00Ogoo000POol00`00Oomoo`3oOol9Ool30022Ool0021oo`03001oogoo0?moo`Eo
o`@008Eoo`0087oo00<007ooOol0ogoo0Woo0`00RGoo000POol00`00Oomoo`3nOol3002<Ool0021o
o`03001oogoo0?aoo`8008moo`0087oo0P00nWoo0`00TGoo000POol00`00Oomoo`3fOol3002DOol0
021oo`03001oogoo0?Aoo`8009Moo`0087oo00<007ooOol0lGoo0`00VGoo000POol00`00Oomoo`3^
Ool3002LOol0021oo`03001oogoo0>]oo`<009moo`0087oo00<007ooOol0j7oo0`00XWoo000POol0
0`00Oomoo`3VOol2002UOol0021oo`03001oogoo0>=oo`<00:Moo`0087oo00<007ooOol0h7oo0`00
ZWoo000POol2003NOol3002]Ool0021oo`03001oogoo0=Yoo`<00;1oo`0087oo00<007ooOol0egoo
0`00/goo000POol00`00Oomoo`3COol4002fOol0021oo`03001oogoo0=1oo`<00;Yoo`0087oo00<0
07ooOol0cGoo0`00_Goo00000gooO^h0000400001@7GOomoogooO^h00`0000<jogooOol00Woo00En
kP00000003[o00Moo`03001oogoo0<]oo`800<1oo`0017oo00=924]oOol017oo00I93UooOomomcP>
Gol3Ool01TT>Gomoogog>0iOo`Ioo`03001oogoo0<Uoo`800<9oo`0017oo00=924]oOol00goo00=n
kP7GOol00Woo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`05Ool00`00Oomoo`37Ool20034Ool000Ao
o`03B@Q;Ogoo00=oo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo00=nkP7GOol01Goo00<007oo
Ool0a7oo0`00aWoo0004Ool00dT8Bgmoo`03Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`03
O^h1egoo00Eoo`<00<9oo`800<Uoo`0017oo00=924]oOol00goo00=^J29kOol00Woo00InkP7GOomo
ofiX8W/3Ool00gk^0MMoo`05Ool00`00Oomoo`30Ool2003;Ool000Aoo`03B@Q;Ogoo00=oo`03O^hR
Ngoo009oo`06KVPRNgooOomnkR9k0goo00=^J29kOol01Goo00<007ooOol0_Goo0`00cGoo00001Woo
KVP0004BB@Q;O`Eoo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol6Ool00`00Oomoo`2kOol2
003@Ool000=oo`03KVP024]o00Eoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl01goo00<007oo
Ool0^7oo0`00dWoo000POol00`00Oomoo`2fOol2003EOol0021oo`03001oogoo0;=oo`<00=Moo`00
87oo00<007ooOol0/Goo0P00fWoo000POol00`00Oomoo`2^Ool3003LOol0021oo`03001oogoo0:ao
o`800=moo`0087oo0P00ZWoo0`00hGoo000POol00`00Oomoo`2VOol3003TOol0021oo`03001oogoo
0:Aoo`800>Moo`0087oo00<007ooOol0XGoo0`00jGoo000POol00`00Oomoo`2NOol3003/Ool0021o
o`03001oogoo09aoo`800>moo`0087oo00<007ooOol0VWoo0P00lGoo000POol00`00Oomoo`2HOol2
003cOol0021oo`03001oogoo09Ioo`800?Eoo`0087oo00<007ooOol0U7oo0P00mgoo000POol2002C
Ool2003iOol0021oo`03001oogoo091oo`800?]oo`0087oo00<007ooOol0SGoo0`00oGoo000POol0
0`00Oomoo`2;Ool2003oOol1Ool0021oo`03001oogoo08Uoo`800?moo`=oo`0087oo00<007ooOol0
Qgoo0P00ogoo1Goo000POol00`00Oomoo`24Ool3003oOol7Ool0021oo`03001oogoo089oo`800?mo
o`Yoo`0087oo00<007ooOol0P7oo0P00ogoo37oo000POol00`00Oomoo`1mOol3003oOol>Ool0021o
o`8007aoo`800?mooa5oo`0087oo00<007ooOol0NGoo0P00ogoo4goo000POol00`00Oomoo`1gOol2
003oOolEOol0021oo`03001oogoo07Aoo`<00?mooaMoo`0087oo00<007ooOol0LWoo0P00ogoo6Woo
000POol00`00Oomoo`1`Ool2003oOolLOol00003OomnkP0000@000040MMoogog>00500001C[oOomo
ogooO^h00`0000<jogooOol01Goo00<007ooOol0KWoo0P00ogoo7Woo0004Ool00dT8Bgmoo`03Ool0
0eg000iOo`02Ool00fi^Bgmoo`02Ool01TT>Gomoogog>0iOo`Ioo`03001oogoo06aoo`800?moob1o
o`0017oo00=924]oOol017oo00=nkP08Bgl01Goo00=nkP7GOol00Woo00=^J29kOol01Goo00<007oo
Ool0JWoo0P00ogoo8Woo0004Ool00dT8Bgmoo`05Ool00gmb800RN`04Ool00fiX8W]oo`02Ool00gk^
0MMoo`05Ool00`00Oomoo`1XOol2003oOolTOol000Aoo`03B@Q;Ogoo00Moo`03B@0RNgoo009oo`03
KVPRNgoo009oo`03O^h1egoo00Eoo`<006Ioo`800?moobIoo`0017oo00=924]oOol027oo00I93Uoo
OomoofiX8W/3Ool00gk^0MMoo`05Ool00`00Oomoo`1TOol2003oOolXOol000Aoo`03B@Q;Ogoo00=o
o`03KVPjogoo009oo`06GL0jogooOomnkR9k0goo00=^J29kOol01Goo00<007ooOol0HWoo0P00ogoo
:Woo00001WooKVP0004BB@Q;O`Aoo`07O^h03UooOomnkP08Bgl00goo00I903[oOomoLR0>Gol6Ool0
0`00Oomoo`1POol2003oOol/Ool000=oo`03KVP024]o00Eoo`05O^h0000000Q;O`04Ool01Gog>000
0008Bgl01goo00<007ooOol0GWoo0P00ogoo;Woo000POol00`00Oomoo`1MOol00`00Oomoo`3oOol^
Ool0021oo`03001oogoo05]oo`800?mooc5oo`0087oo00<007ooOol0FGoo0P00ogoo<goo000POol0
0`00Oomoo`1GOol2003oOoleOol0021oo`03001oogoo05Eoo`800?moocMoo`0087oo0P00E7oo0P00
ogoo>Goo000POol00`00Oomoo`1AOol2003oOolkOol0021oo`03001oogoo04moo`800?mooceoo`00
87oo00<007ooOol0CGoo0P00ogoo?goo000POol00`00Oomoo`1;Ool2003oOom1Ool0021oo`03001o
ogoo04Uoo`800?mood=oo`0087oo00<007ooOol0Agoo0P00ogooAGoo000POol00`00Oomoo`16Ool0
0`00Oomoo`3oOom5Ool0021oo`03001oogoo04Aoo`800?moodQoo`0087oo00<007ooOol0@Woo0P00
ogooBWoo000POol20011Ool2003oOom<Ool0021oo`03001oogoo03ioo`800?moodioo`0087oo00<0
07ooOol0?Goo00<007ooOol0ogooCWoo000POol00`00Oomoo`0kOol2003oOomAOol0021oo`03001o
ogoo03Uoo`800?mooe=oo`0087oo00<007ooOol0=goo0P00ogooEGoo000POol00`00Oomoo`0eOol2
003oOomGOol0021oo`03001oogoo03=oo`800?mooeUoo`0087oo00<007ooOol0<Goo0P00ogooFgoo
000POol00`00Oomoo`0_Ool2003oOomMOol0021oo`8002moo`03001oogoo0?mooeeoo`0087oo00<0
07ooOol0;7oo0P00ogooH7oo000POol00`00Oomoo`0ZOol2003oOomROol0021oo`03001oogoo02Uo
o`03001oogoo0?moof9oo`0087oo00<007ooOol09goo0P00ogooIGoo000POol00`00Oomoo`0UOol2
003oOomWOol0021oo`03001oogoo02=oo`800?moofUoo`0000=oogk^0000100000<1egooOol00Woo
00EoLR00000003[o00=oo`05O^h00000000jo`07Ool00`00Oomoo`0ROol00`00Oomoo`3oOomYOol0
00Aoo`03B@Q;Ogoo00Moo`03GL0jogoo00=oo`06B@iOogooOoLh3Uoo1Woo00<007ooOol087oo0P00
ogooK7oo0004Ool00dT8Bgmoo`07Ool00eg0>_moo`02Ool00gk^0MMoo`02Ool00fiX8W]oo`05Ool0
0`00Oomoo`0NOol2003oOom^Ool000Aoo`03B@Q;Ogoo00=oo`03KVP0000000<00005>_moogooKVPR
N`03Ool00gk^0MMoo`05Ool3000MOol00`00Oomoo`3oOom^Ool000Aoo`03B@Q;Ogoo00=oo`06O^h0
3UooOomM`3[o0goo00=^J29kOol00Woo00=nkP7GOol01Goo00<007ooOol06goo0P00ogooLGoo0004
Ool00dT8Bgmoo`04Ool01FiX0MMooeg0>_l00goo00=^J29kOol00Woo00=nkP7GOol01Goo00<007oo
Ool06Goo0P00ogooLgoo0004Ool00dT8Bgmoo`05Ool014T08W]M`3[o0goo00=nkR9kOol00Woo00=^
J29kOol01Goo00<007ooOol067oo00<007ooOol0ogooLgoo00001WooKVP0004BB@Q;O`Ioo`04Og8P
2240>_l4Ool01TT0>_moogmb80iOo`Ioo`03001oogoo01Ioo`800?moogIoo`000goo00=^J008Bgl0
1goo00=nkP00>_l017oo00EomcP0000024]o00Moo`03001oogoo01Aoo`800?moogQoo`0087oo00<0
07ooOol04Woo0P00ogooNWoo000POol00`00Oomoo`0AOol00`00Oomoo`3oOomjOol0021oo`03001o
ogoo00moo`800?moogeoo`0087oo00<007ooOol03Goo0P00ogooOgoo000POol2000=Ool00`00Oomo
o`3oOomoOol0021oo`03001oogoo00Yoo`800?mooh9oo`0087oo00<007ooOol02Goo00<007ooOol0
ogooPWoo000POol00`00Oomoo`07Ool2003oOon5Ool0021oo`03001oogoo00Ioo`03001oogoo0?mo
ohEoo`0087oo00<007ooOol017oo0P00ogooR7oo000POol00`00Oomoo`03Ool00`00Oomoo`3oOon8
Ool0021oo`04001oogooOol2003oOon;Ool0021oo`04001oogoo003oOon=Ool0021oo`<00?moohio
o`0087oo00<007ooOol0ogooSWoo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2983.2, 21.3608, 139.475, \
0.746278}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((g[theta\ 60^2] - T0)\)/\((g[10^7] - T0)\)\)], "Input"],

Cell[BoxData[
    \(0.6321205588285578`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[200\ 10^3]\)], "Input"],

Cell[BoxData[
    \(28.399343696906215`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - 1/E\  // N\)], "Input"],

Cell[BoxData[
    \(0.6321205588285577`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(theta\ 60^2\)], "Input"],

Cell[BoxData[
    \(34953.095416250006`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(10^5/60^2\  // N\)], "Input"],

Cell[BoxData[
    \(27.77777777777778`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trise = rho\ c\ V\ 20/Q\)], "Input"],

Cell[BoxData[
    \(Power::"infy" \(\(:\)\(\ \)\) 
      "Infinite expression \!\(1\/0\) encountered."\)], "Message"],

Cell[BoxData[
    InterpretationBox["ComplexInfinity",
      DirectedInfinity[ ]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trise/60^2\)], "Input"],

Cell[BoxData[
    InterpretationBox["ComplexInfinity",
      DirectedInfinity[ ]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(z = 
        FindRoot[
          g[t] \[Equal] 20 + Rm\ Q + T0, {t, 
            100}];\)\), "\[IndentingNewLine]", 
    \(triseCcond = z[\([1, 2]\)]\)}], "Input"],

Cell[BoxData[
    \(\(-5306.090075605367`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(triseCcond/60^2 // N\)], "Input"],

Cell[BoxData[
    \(\(-1.4739139098903797`\)\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 959}},
WindowSize->{1391, 921},
WindowMargins->{{Automatic, 0}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 241, 6, 68, "Input"],
Cell[1998, 59, 54, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[2077, 64, 101, 2, 89, "Section"],
Cell[2181, 68, 153, 2, 68, "Input"],
Cell[2337, 72, 127, 3, 42, "Input"],
Cell[2467, 77, 76, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[2568, 82, 47, 1, 42, "Input"],
Cell[2618, 85, 287, 4, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2954, 95, 117, 3, 89, "Section"],
Cell[3074, 100, 275, 8, 177, "Text"],
Cell[3352, 110, 44, 1, 42, "Input"],
Cell[3399, 113, 555, 11, 250, "Input"],
Cell[3957, 126, 153, 2, 68, "Input"],

Cell[CellGroupData[{
Cell[4135, 132, 92, 2, 68, "Input"],
Cell[4230, 136, 53, 1, 41, "Output"]
}, Open  ]],
Cell[4298, 140, 59, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[4382, 144, 107, 2, 68, "Input"],
Cell[4492, 148, 58, 1, 41, "Output"]
}, Open  ]],
Cell[4565, 152, 39, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[4629, 156, 70, 1, 42, "Input"],
Cell[4702, 159, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4791, 165, 47, 1, 42, "Input"],
Cell[4841, 168, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4931, 174, 49, 1, 42, "Input"],
Cell[4983, 177, 40, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5060, 183, 45, 1, 42, "Input"],
Cell[5108, 186, 42, 1, 41, "Output"]
}, Open  ]],
Cell[5165, 190, 127, 3, 42, "Input"],
Cell[5295, 195, 76, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[5396, 200, 47, 1, 42, "Input"],
Cell[5446, 203, 154, 3, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5637, 211, 42, 1, 42, "Input"],
Cell[5682, 214, 37, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5756, 220, 37, 1, 42, "Input"],
Cell[5796, 223, 39, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5872, 229, 40, 1, 42, "Input"],
Cell[5915, 232, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6005, 238, 50, 1, 42, "Input"],
Cell[6058, 241, 37, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6132, 247, 38, 1, 42, "Input"],
Cell[6173, 250, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6245, 256, 44, 1, 42, "Input"],
Cell[6292, 259, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6381, 265, 104, 2, 42, "Input"],
Cell[6488, 269, 21827, 470, 279, 3403, 238, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28352, 744, 111, 2, 42, "Input"],
Cell[28466, 748, 23169, 529, 279, 4112, 289, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51672, 1282, 77, 1, 42, "Input"],
Cell[51752, 1285, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51842, 1291, 45, 1, 42, "Input"],
Cell[51890, 1294, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51980, 1300, 47, 1, 42, "Input"],
Cell[52030, 1303, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52120, 1309, 44, 1, 42, "Input"],
Cell[52167, 1312, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52257, 1318, 49, 1, 42, "Input"],
Cell[52309, 1321, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52398, 1327, 56, 1, 42, "Input"],
Cell[52457, 1330, 117, 2, 51, "Message"],
Cell[52577, 1334, 93, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52707, 1341, 43, 1, 42, "Input"],
Cell[52753, 1344, 93, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52883, 1351, 186, 5, 68, "Input"],
Cell[53072, 1358, 57, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53166, 1364, 53, 1, 42, "Input"],
Cell[53222, 1367, 58, 1, 41, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

