(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     76265,       2036]*)
(*NotebookOutlinePosition[     76909,       2058]*)
(*  CellTagsIndexPosition[     76865,       2054]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    StyleBox[\(Off[General::spell]\),
      FormatType->StandardForm,
      FontFamily->"Courier New"], "\n", 
    StyleBox[\(Off[General::spell1]\),
      FormatType->StandardForm,
      FontFamily->"Courier New"]}], "Input"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
General transient temperature solution with negligible internal resistance\
\>", "Section"],

Cell[BoxData[{
    \(\(a = h\ A/\((rho\ c\ V)\);\)\), "\[IndentingNewLine]", 
    \(\(b = Q/\((rho\ c\ V)\) + h\ A\ Tinf/\((rho\ c\ V)\);\)\)}], "Input"],

Cell[BoxData[
    \(\(f = 
        DSolve[{\(T'\)[t] + a\ T[t]\  == \ b, T[0] \[Equal] T0}, T[t], 
          t];\)\)], "Input"],

Cell[BoxData[
    \(g[t_] := Evaluate[f[\([1, 1, 2]\)] + Q\ Rm]\)], "Input"],

Cell[BoxData[
    \(Simplify[g[t]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Thermal Time Constant Calculation for Stage 0-1 Actuator Coils\
\>", "Section"],

Cell["\<\
From Algor FEA results on a single stage 0-1 actuator, the pillar and voice \
coil mount are all about the same temperature.
Rp = resistance for heat flow from the pillar, C/W
Rm = resistance for heat flow from the coil to the pillar, C/W (assumed to \
have no significant thermal mass)
R = Rp + Rm = total resistance (at low temperature/power, dominated by \
conduction)\
\>", "Text"],

Cell[BoxData[{
    \(\(Rp = 1.3;\)\), "\[IndentingNewLine]", 
    \(\(Rm = 0.2;\)\), "\[IndentingNewLine]", 
    \(\(R = Rp + Rm;\)\)}], "Input"],

Cell[BoxData[{
    \(\(c = 896;\)\), "\[IndentingNewLine]", 
    \(\(rho = 2700;\)\), "\[IndentingNewLine]", 
    \(\(V = 0.027;\)\), "\[IndentingNewLine]", 
    \(\(A = 0.045;\)\), "\[IndentingNewLine]", 
    \(\(h = 1/\((Rp\ A)\);\)\), "\[IndentingNewLine]", 
    \(\(Q = 20;\)\), "\[IndentingNewLine]", 
    \(\(T0 = 20;\)\), "\[IndentingNewLine]", 
    \(\(Tinf = 20;\)\), "\[IndentingNewLine]", 
    \(\(k = 171;\)\)}], "Input"],

Cell[BoxData[{
    \(\(a = h\ A/\((rho\ c\ V)\);\)\), "\[IndentingNewLine]", 
    \(\(b = Q/\((rho\ c\ V)\) + h\ A\ Tinf/\((rho\ c\ V)\);\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L = V/A;\)\), "\[IndentingNewLine]", 
    \(Bi = h\ L/k\)}], "Input"],

Cell[BoxData[
    \(0.0599790073474284`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(diff = k/\((c\ rho)\);\)\), "\[IndentingNewLine]", 
    \(Bi\ diff/L^2\)}], "Input"],

Cell[BoxData[
    \(0.000011776632147002518`\)], "Output"]
}, Open  ]],

Cell["Time constant in hours:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theta = \((rho\ c\ L)\)/\((h\ 60^2)\)\)], "Input"],

Cell[BoxData[
    \(23.5872`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - 1/E\  // N\)], "Input"],

Cell[BoxData[
    \(0.6321205588285577`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(0.63\ 150\  + 20\)], "Input"],

Cell[BoxData[
    \(114.5`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(27.216\ 60^2\)], "Input"],

Cell[BoxData[
    \(97977.6`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f = 
        DSolve[{\(T'\)[t] + a\ T[t]\  == \ b, T[0] \[Equal] T0}, T[t], 
          t];\)\)], "Input"],

Cell[BoxData[
    \(g[t_] := Evaluate[f[\([1, 1, 2]\)] + Q\ Rm]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[g[t]]\)], "Input"],

Cell[BoxData[
    \(\(\(50.00000000000001`\)\(\[InvisibleSpace]\)\) - 
      26.000000000000004`\ \[ExponentialE]\^\(\(-0.000011776632147002516`\)\ \
t\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T0 + Q\ R\)], "Input"],

Cell[BoxData[
    \(50.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[0]\)], "Input"],

Cell[BoxData[
    \(24.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[10^6]\)], "Input"],

Cell[BoxData[
    \(49.99980026830339`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T0 + Q/\((h\ A)\)\)], "Input"],

Cell[BoxData[
    \(46.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Q\ Rm\)], "Input"],

Cell[BoxData[
    \(4.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g[t], {t, 0, 3\ theta\ 60^2}, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 3.73861e-006 -0.55708 0.0238248 [
[.21074 .02604 -15 -9 ]
[.21074 .02604 15 0 ]
[.39767 .02604 -18 -9 ]
[.39767 .02604 18 0 ]
[.5846 .02604 -18 -9 ]
[.5846 .02604 18 0 ]
[.77153 .02604 -18 -9 ]
[.77153 .02604 18 0 ]
[.95846 .02604 -18 -9 ]
[.95846 .02604 18 0 ]
[.01131 .15766 -12 -4.5 ]
[.01131 .15766 0 4.5 ]
[.01131 .27679 -12 -4.5 ]
[.01131 .27679 0 4.5 ]
[.01131 .39591 -12 -4.5 ]
[.01131 .39591 0 4.5 ]
[.01131 .51504 -12 -4.5 ]
[.01131 .51504 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21074 .03854 m
.21074 .04479 L
s
[(50000)] .21074 .02604 0 1 Mshowa
.39767 .03854 m
.39767 .04479 L
s
[(100000)] .39767 .02604 0 1 Mshowa
.5846 .03854 m
.5846 .04479 L
s
[(150000)] .5846 .02604 0 1 Mshowa
.77153 .03854 m
.77153 .04479 L
s
[(200000)] .77153 .02604 0 1 Mshowa
.95846 .03854 m
.95846 .04479 L
s
[(250000)] .95846 .02604 0 1 Mshowa
.125 Mabswid
.0612 .03854 m
.0612 .04229 L
s
.09858 .03854 m
.09858 .04229 L
s
.13597 .03854 m
.13597 .04229 L
s
.17335 .03854 m
.17335 .04229 L
s
.24813 .03854 m
.24813 .04229 L
s
.28551 .03854 m
.28551 .04229 L
s
.3229 .03854 m
.3229 .04229 L
s
.36028 .03854 m
.36028 .04229 L
s
.43506 .03854 m
.43506 .04229 L
s
.47244 .03854 m
.47244 .04229 L
s
.50983 .03854 m
.50983 .04229 L
s
.54722 .03854 m
.54722 .04229 L
s
.62199 .03854 m
.62199 .04229 L
s
.65937 .03854 m
.65937 .04229 L
s
.69676 .03854 m
.69676 .04229 L
s
.73415 .03854 m
.73415 .04229 L
s
.80892 .03854 m
.80892 .04229 L
s
.8463 .03854 m
.8463 .04229 L
s
.88369 .03854 m
.88369 .04229 L
s
.92108 .03854 m
.92108 .04229 L
s
.99585 .03854 m
.99585 .04229 L
s
.25 Mabswid
0 .03854 m
1 .03854 L
s
.02381 .15766 m
.03006 .15766 L
s
[(30)] .01131 .15766 1 0 Mshowa
.02381 .27679 m
.03006 .27679 L
s
[(35)] .01131 .27679 1 0 Mshowa
.02381 .39591 m
.03006 .39591 L
s
[(40)] .01131 .39591 1 0 Mshowa
.02381 .51504 m
.03006 .51504 L
s
[(45)] .01131 .51504 1 0 Mshowa
.125 Mabswid
.02381 .06236 m
.02756 .06236 L
s
.02381 .08619 m
.02756 .08619 L
s
.02381 .11001 m
.02756 .11001 L
s
.02381 .13384 m
.02756 .13384 L
s
.02381 .18149 m
.02756 .18149 L
s
.02381 .20531 m
.02756 .20531 L
s
.02381 .22914 m
.02756 .22914 L
s
.02381 .25296 m
.02756 .25296 L
s
.02381 .30061 m
.02756 .30061 L
s
.02381 .32444 m
.02756 .32444 L
s
.02381 .34826 m
.02756 .34826 L
s
.02381 .37209 m
.02756 .37209 L
s
.02381 .41974 m
.02756 .41974 L
s
.02381 .44356 m
.02756 .44356 L
s
.02381 .46739 m
.02756 .46739 L
s
.02381 .49121 m
.02756 .49121 L
s
.02381 .01472 m
.02756 .01472 L
s
.02381 .53886 m
.02756 .53886 L
s
.02381 .56268 m
.02756 .56268 L
s
.02381 .58651 m
.02756 .58651 L
s
.02381 .61033 m
.02756 .61033 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .0857 L
.10458 .15387 L
.14415 .21015 L
.18221 .25805 L
.22272 .30311 L
.26171 .34137 L
.30316 .37721 L
.34309 .40758 L
.3815 .4334 L
.42237 .45765 L
.46172 .47823 L
.49955 .49575 L
.53984 .51224 L
.57861 .52626 L
.61984 .5394 L
.65954 .55054 L
.69774 .56002 L
.73838 .56893 L
.77751 .57649 L
.81909 .58357 L
.85916 .58957 L
.89771 .59467 L
.93871 .59945 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo001>Ool01Eg000000000>_l0
17oo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l017oo00EnkP000000
03[o01ioo`03O^h0000000<000050MMoogooOomnkP0300000c[oOomoo`02Ool01Gk^00000000>_l0
17oo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l06Goo00=nkP000000
0`0000D1egooOomooeg000<00003>_moogoo009oo`05O^h00000000jo`04Ool01Gk^00000000>_l0
17oo00EnkP00000003[o00Aoo`05O^h00000000jo`0HOol00gog>000000400001C[oOomoogooO^h0
0`0000<jogooOol00Woo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l0
17oo00EnkP00000003[o01Uoo`03OoLh000000@00005>_moogooOomM`00300000c[oOomoo`02Ool0
1Gk^00000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l0
0goo000GOol00`00Oomoo`0cOol01eg00MMoogooOg8P03[o00=oo`06B@iOogooOoLh3Uoo0goo00I9
3UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo87oo00=924]oOol017oo
00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomo
mcP>Gol3Ool01TT>Gomoogog>0iOoa]oo`03B@Q;Ogoo00=oo`07GL01egooOomoLR00>_l00goo00I9
3UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>
GolHOol00eg000iOo`02Ool00fi^Bgmoo`02Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo
0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo6Goo00=M`00>
Gol00Woo00I^KT]oOomooeg00ML2Ool00gmb800jo`03Ool01TT>Gomoogog>0iOo`=oo`06B@iOogoo
OoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`9oo`005goo00<007ooOol0>7oo
00InkP7GOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomo
ogk^0ML3Ool00fiX8W]oo`0OOol00dT8Bgmoo`03Ool00gk^0MMoo`02Ool01ViX8W]oogooO^h1e`=o
o`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`03KVPRNgoo
01Yoo`03B@Q;Ogoo00Qoo`06O^h1egooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogoo
O^h1e`=oo`06KVPRNgooOomnkP7G0goo00=^J29kOol067oo00=nkP08Bgl01Goo00=nkP7GOol00Woo
00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomo
ogk^0ML3Ool00fiX8W]oo`0IOol00gk^00Q;O`0:Ool01Wk^0MMoogooO^h1e`=oo`06KVPRNgooOomn
kP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`03KVPRNgoo005oo`005goo00<0
07ooOol0>7oo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo
00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0OOol00dT8Bgmoo`03Ool00fiX8W]oo`02Ool01Wk^0MMo
ogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=o
o`03O^h1egoo01Yoo`03B@Q;Ogoo00Qoo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool0
1Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol06Goo00=oLR008W/017oo00=^
J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo
00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0JOol00gmb800RN`09Ool01Wk^0MMoogooKVPRN`=oo`06
O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo005o
o`005goo00<007ooOol0>7oo00I903[oOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egoo
Oom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0OOol00dT8Bgmoo`03Ool00fiX8W]oo`02
Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMo
ogooKVPRN`=oo`03O^h1egoo01Yoo`03B@Q;Ogoo00Qoo`06B@0jogooOom^J29k0goo00InkP7GOomo
ofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol06goo00=9029k
Ool00Woo00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egoo
Oom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0LOol00dT08W]oo`07Ool01TT0>_moogoo
KVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03
O^h1egoo005oo`005goo00<007ooOol0<goo00=omcP000000P0000HRNgooOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0OOol0
0dT8Bgmoo`03Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00In
kP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo01Yoo`03B@Q;Ogoo00=oo`03OoLh
0000008000068W]oogooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06
O^h1egooOom^J29k0goo00=nkP7GOol077oo00I93UooOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=o
o`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo
01eoo`06B@iOogooOomomcP00`0000HRNgooOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1
egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`01Ool001Moo`03001oogoo03=oo`03
OoLh3Uoo00Ioo`03O^hRNgoo009oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool01ViX
8W]oogooO^hRN`=oo`03KVPRNgoo01moo`03B@Q;Ogoo00=oo`03O^hRNgoo009oo`06KVPRNgooOomn
kR9k0goo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00=^
J29kOol06Woo00=924]oOol00goo00=omcP>Gol01Woo00=nkR9kOol00Woo00I^J29kOomoogk^8W/3
Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00=^J29kOol05goo00=^J3[oOol00Woo
00IM`3[oOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomo
ogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`03KVPRNgoo01Qoo`03KVPjogoo009oo`07GL0jogooOomo
mcP>Gol01Woo00=nkR9kOol00Woo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPR
NgooOomnkR9k0goo00=^J29kOol00Goo000GOol2000dOol00gog>0iOo`07Ool01TT0>_moogmb80iO
o`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOoaeoo`05KVP0
004BB@Q;O`05Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3
Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo67oo00E^J0000A9924]o00Aoo`03OoLh3Uoo
00Moo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0j
ogooOg8P3Uoo67oo00MnkP0>Gomoogk^00Q;O`03Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P
3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo6Goo00Mn
kP0>Gomoogk^00Q;O`02Ool00gog>0iOo`07Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo
0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`9oo`005goo0P00=7oo00=omcP000000P00
00<03UooOol00Woo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo
00EomcP0000024]o021oo`03KVP024]o00Eoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo
00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl06goo00=^J008Bgl017oo
00=omcP000000P0000<03UooOol00Woo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog
>0000008Bgl017oo00EomcP0000024]o01Yoo`05O^h0000000Q;O`04Ool01Gog>0000008Bgl017oo
00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o
01]oo`05O^h0000000Q;O`03Ool00gog>000000200000`0>Gomoo`02Ool01Gog>0000008Bgl017oo
00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl00goo000GOol2003oOonH
Ool001Moo`03001oo`000?mooiMoo`005goo00<007oo0000ogooUgoo000GOol01000Oomoo`00ogoo
UWoo000GOol01000Oomoo`00ogooUWoo000GOol01@00Oomoogoo0000ogooUGoo000GOol01@00Oomo
ogoo0000ogooUGoo000GOol00`00Oomoo`02Ool00`00Oomoo`3oOonBOol000eoool009T000]oo`00
5goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
3Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
3Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0
37oo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0
37oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
37oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02Woo000GOol00`00Oomoo`03Ool00`00
Oomoo`13Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`1:Ool00`00
Oomoo`0IOol001Moo`03001oogoo00Aoo`03001oogoo0?mooi1oo`005goo00<007ooOol017oo00<0
07ooOol0ogooT7oo000GOol00`00Oomoo`05Ool00`00Oomoo`3oOon?Ool001Moo`03001oogoo00Eo
o`03001oogoo0?moohmoo`005goo00<007ooOol01Woo00<007ooOol0ogooSWoo000GOol00`00Oomo
o`06Ool00`00Oomoo`3oOon>Ool001Moo`8000Qoo`03001oogoo0?mooheoo`005goo00<007ooOol0
1goo00<007ooOol0ogooSGoo000GOol00`00Oomoo`08Ool00`00Oomoo`3oOon<Ool001Moo`03001o
ogoo00Qoo`03001oogoo0?moohaoo`005goo00<007ooOol02Goo00<007ooOol0ogooRgoo000GOol0
0`00Oomoo`09Ool00`00Oomoo`3oOon;Ool001Moo`03001oogoo00Yoo`03001oogoo0?moohYoo`00
5goo00<007ooOol02Woo00<007ooOol0ogooRWoo000GOol00`00Oomoo`0;Ool00`00Oomoo`3oOon9
Ool001Moo`03001oogoo00]oo`03001oogoo0?moohUoo`005goo0P003Goo00<007ooOol0ogooR7oo
000GOol00`00Oomoo`0=Ool00`00Oomoo`3oOon7Ool001Moo`03001oogoo00eoo`03001oogoo0?mo
ohMoo`005goo00<007ooOol03Woo00<007ooOol0ogooQWoo000GOol00`00Oomoo`0?Ool00`00Oomo
o`3oOon5Ool001Moo`03001oogoo00moo`03001oogoo0?moohEoo`005goo00<007ooOol047oo00<0
07ooOol0ogooQ7oo000GOol00`00Oomoo`0@Ool00`00Oomoo`3oOon4Ool001Moo`03001oogoo015o
o`03001oogoo0?mooh=oo`005goo00<007ooOol04Woo00<007ooOol0ogooPWoo000GOol2000COol0
0`00Oomoo`3oOon2Ool001Moo`03001oogoo01=oo`03001oogoo0?mooh5oo`005goo00<007ooOol0
57oo00<007ooOol0ogooP7oo000GOol00`00Oomoo`0DOol00`00Oomoo`3oOon0Ool001Moo`03001o
ogoo01Eoo`03001oogoo0?moogmoo`005goo00<007ooOol05Woo00<007ooOol0ogooOWoo000GOol0
0`00Oomoo`0FOol00`00Oomoo`3oOomnOol001Moo`03001oogoo01Moo`03001oogoo0?moogeoo`00
5goo00<007ooOol067oo00<007ooOol0ogooO7oo000GOol00`00Oomoo`0HOol00`00Oomoo`3oOoml
Ool001Moo`8001Yoo`03001oogoo0?moog]oo`005goo00<007ooOol06Goo00<007ooOol0ogooNgoo
000GOol00`00Oomoo`0JOol00`00Oomoo`3oOomjOol001Moo`03001oogoo01]oo`03001oogoo0?mo
ogUoo`005goo00<007ooOol06goo00<007ooOol0ogooNGoo000GOol00`00Oomoo`0LOol00`00Oomo
o`3oOomhOol0009oo`05GL000000000RN`04Ool01Gk^00000000>_l01goo00<007ooOol07Goo00<0
07ooOol0ogooMgoo00000gooGL01e`02Ool00gog>00RN`03Ool01TT>Gomoogog>0iOo`Ioo`03001o
ogoo01eoo`03001oogoo0?moogMoo`001Woo00InkP7GOomoogk^0ML3Ool00fiX8W]oo`05Ool00`00
Oomoo`0NOol00`00Oomoo`3oOomfOol000Eoo`03Og8P24]o009oo`03KVPRNgoo009oo`03O^h1egoo
00Eoo`<001moo`03001oogoo0?moogEoo`000goo00A^J00000Q;O`=oo`03KVPRNgoo009oo`03O^h1
egoo00Eoo`03001oogoo01moo`03001oogoo0?moogEoo`001Goo00=oLR08Bgl00Woo00=^J29kOol0
0Woo00=nkP7GOol01Goo00<007ooOol087oo00<007ooOol0ogooM7oo0006Ool01Ug0>_moogooO^hR
N`=oo`03KVPRNgoo00Eoo`03001oogoo025oo`03001oogoo0?moog=oo`0000Qoogk^00Q;OgooOg8P
24]o0goo00I903[oOomoLR0>Gol6Ool00`00Oomoo`0QOol00`00Oomoo`3oOomcOol0009oo`05Og8P
0000000jo`04Ool01Gog>0000008Bgl01goo00<007ooOol08Woo00<007ooOol0ogooLWoo000GOol0
0`00Oomoo`0SOol00`00Oomoo`3oOomaOol001Moo`03001oogoo02Aoo`03001oogoo0?moog1oo`00
5goo00<007ooOol097oo00<007ooOol0ogooL7oo000GOol00`00Oomoo`0UOol00`00Oomoo`3oOom_
Ool001Moo`8002Moo`03001oogoo0?moofioo`005goo00<007ooOol09Woo00<007ooOol0ogooKWoo
000GOol00`00Oomoo`0WOol00`00Oomoo`3oOom]Ool001Moo`03001oogoo02Qoo`03001oogoo0?mo
ofaoo`005goo00<007ooOol0:7oo00<007ooOol0ogooK7oo000GOol00`00Oomoo`0YOol00`00Oomo
o`3oOom[Ool001Moo`03001oogoo02Yoo`03001oogoo0?moofYoo`005goo00<007ooOol0:goo00<0
07ooOol0ogooJGoo000GOol00`00Oomoo`0[Ool00`00Oomoo`3oOomYOol001Moo`03001oogoo02ao
o`03001oogoo0?moofQoo`005goo0P00;Woo00<007ooOol0ogooIgoo000GOol00`00Oomoo`0]Ool0
0`00Oomoo`3oOomWOol001Moo`03001oogoo02ioo`03001oogoo0?moofIoo`005goo00<007ooOol0
;goo00<007ooOol0ogooIGoo000GOol00`00Oomoo`0`Ool00`00Oomoo`3oOomTOol001Moo`03001o
ogoo031oo`03001oogoo0?moofAoo`005goo00<007ooOol0<Goo00<007ooOol0ogooHgoo000GOol0
0`00Oomoo`0bOol00`00Oomoo`3oOomROol001Moo`03001oogoo03=oo`03001oogoo0?moof5oo`00
5goo0P00=Goo00<007ooOol0ogooH7oo000GOol00`00Oomoo`0dOol00`00Oomoo`3oOomPOol001Mo
o`03001oogoo03Eoo`03001oogoo0?mooemoo`005goo00<007ooOol0=Woo00<007ooOol0ogooGWoo
000GOol00`00Oomoo`0gOol00`00Oomoo`3oOomMOol001Moo`03001oogoo03Moo`03001oogoo0?mo
oeeoo`005goo00<007ooOol0>7oo00<007ooOol0ogooG7oo000GOol00`00Oomoo`0iOol00`00Oomo
o`3oOomKOol001Moo`03001oogoo03Yoo`03001oogoo0?mooeYoo`005goo00<007ooOol0>goo00<0
07ooOol0ogooFGoo000GOol2000lOol00`00Oomoo`3oOomIOol001Moo`03001oogoo03aoo`03001o
ogoo0?mooeQoo`005goo00<007ooOol0?Goo00<007ooOol0ogooEgoo000GOol00`00Oomoo`0nOol0
0`00Oomoo`3oOomFOol001Moo`03001oogoo03moo`03001oogoo0?mooeEoo`005goo00<007ooOol0
@7oo00<007ooOol0ogooE7oo0002Ool01Eg0000000008W/017oo00EM`000000003[o00Moo`03001o
ogoo045oo`03001oogoo0?mooe=oo`0000=ooeg00ML00Woo00=omcP08W/00Woo00MM`07GOomoogmb
800jo`06Ool00`00Oomoo`11Ool00`00Oomoo`3oOomCOol000Ioo`03O^h1egoo00Ioo`03O^h1egoo
00Eoo`03001oogoo049oo`03001oogoo0?mooe9oo`001Goo00=oLR08Bgl01goo00=nkP7GOol01Goo
00<007ooOol0@goo00<007ooOol0ogooDGoo0003Ool016iX000024]o27oo00=903[oOol01Goo0`00
A7oo00<007ooOol0ogooD7oo0005Ool00gmb80Q;O`02Ool00gog>000000200000b9kOomoo`05Ool0
0`00Oomoo`15Ool00`00Oomoo`3oOom?Ool000Ioo`07GL0jogooOomomcP>Gol02Woo00<007ooOol0
AWoo00<007ooOol0ogooCWoo000027ooO^h024]oOomoLR08Bgl2Ool00gog>0iOo`0:Ool00`00Oomo
o`17Ool00`00Oomoo`3oOom=Ool0009oo`05Og8P0000000jo`03Ool00gog>000000200000`0>Gomo
o`05Ool00`00Oomoo`18Ool00`00Oomoo`3oOom<Ool001Moo`03001oogoo04Uoo`03001oogoo0?mo
od]oo`005goo00<007ooOol0BWoo00<007ooOol0ogooBWoo000GOol00`00Oomoo`1:Ool00`00Oomo
o`3oOom:Ool001Moo`03001oogoo04]oo`03001oogoo0?moodUoo`005goo00<007ooOol0C7oo00<0
07ooOol0ogooB7oo000GOol2001>Ool00`00Oomoo`3oOom7Ool001Moo`03001oogoo04ioo`03001o
ogoo0?moodIoo`005goo00<007ooOol0Cgoo00<007ooOol0ogooAGoo000GOol00`00Oomoo`1@Ool0
0`00Oomoo`3oOom4Ool001Moo`03001oogoo055oo`03001oogoo0?mood=oo`005goo00<007ooOol0
DWoo00<007ooOol0ogoo@Woo000GOol00`00Oomoo`1COol00`00Oomoo`3oOom1Ool001Moo`03001o
ogoo05Aoo`03001oogoo0?mood1oo`005goo00<007ooOol0EGoo00<007ooOol0ogoo?goo000GOol2
001GOol2003oOoloOol001Moo`03001oogoo05Qoo`03001oogoo0?moocaoo`005goo00<007ooOol0
FGoo00<007ooOol0ogoo>goo000GOol00`00Oomoo`1JOol00`00Oomoo`3oOoljOol001Moo`03001o
ogoo05]oo`03001oogoo0?moocUoo`005goo00<007ooOol0G7oo00<007ooOol0ogoo>7oo000GOol0
0`00Oomoo`1MOol00`00Oomoo`3oOolgOol001Moo`03001oogoo05ioo`03001oogoo0?moocIoo`00
5goo00<007ooOol0Ggoo00<007ooOol0ogoo=Goo000GOol00`00Oomoo`1POol00`00Oomoo`3oOold
Ool001Moo`80069oo`03001oogoo0?mooc=oo`005goo00<007ooOol0HWoo00<007ooOol0ogoo<Woo
000GOol00`00Oomoo`1SOol00`00Oomoo`3oOolaOol001Moo`03001oogoo06Aoo`03001oogoo0?mo
oc1oo`005goo00<007ooOol0IGoo00<007ooOol0ogoo;goo000GOol00`00Oomoo`1VOol2003oOol_
Ool001Moo`03001oogoo06Qoo`03001oogoo0?moobaoo`005goo00<007ooOol0JGoo00<007ooOol0
ogoo:goo000GOol00`00Oomoo`1ZOol00`00Oomoo`3oOolZOol001Moo`03001oogoo06]oo`03001o
ogoo0?moobUoo`005goo0P00KGoo00<007ooOol0ogoo:7oo000GOol00`00Oomoo`1]Ool00`00Oomo
o`3oOolWOol001Moo`03001oogoo06ioo`03001oogoo0?moobIoo`005goo00<007ooOol0Kgoo0P00
ogoo9Woo000GOol00`00Oomoo`1aOol00`00Oomoo`3oOolSOol001Moo`03001oogoo079oo`03001o
ogoo0?moob9oo`000goo00EoLR00000003[o00=oo`05O^h00000000jo`07Ool00`00Oomoo`1cOol2
003oOolROol000Eoo`03GL0jogoo00=oo`06B@iOogooOoLh3Uoo1Woo00<007ooOol0MGoo00<007oo
Ool0ogoo7goo0005Ool00eg0>_moo`02Ool00gk^0MMoo`02Ool00fiX8W]oo`05Ool00`00Oomoo`1f
Ool2003oOolOOol00003Oom^J00000@00005>_moogooKVPRN`03Ool00gk^0MMoo`05Ool3001hOol0
0`00Oomoo`3oOolLOol00007OomnkP0>Gomooeg0>_l00goo00=^J29kOol00Woo00=nkP7GOol01Goo
00<007ooOol0NGoo0P00ogoo77oo0002Ool01FiX0MMooeg0>_l00goo00=^J29kOol00Woo00=nkP7G
Ool01Goo00<007ooOol0Ngoo00<007ooOol0ogoo6Goo0003Ool014T08W]M`3[o0goo00=nkR9kOol0
0Woo00=^J29kOol01Goo00<007ooOol0O7oo00<007ooOol0ogoo67oo0003Ool017mb80PQ03[o17oo
00I903[oOomoLR0>Gol6Ool00`00Oomoo`1mOol2003oOolHOol000Aoo`03O^h003[o00Aoo`05OoLh
000000Q;O`07Ool00`00Oomoo`1oOol00`00Oomoo`3oOolEOol001Moo`03001oogoo081oo`800?mo
oaEoo`005goo00<007ooOol0PWoo00<007ooOol0ogoo4Woo000GOol00`00Oomoo`23Ool00`00Oomo
o`3oOolAOol001Moo`03001oogoo08Aoo`800?mooa5oo`005goo0P00Qgoo00<007ooOol0ogoo3Woo
000GOol00`00Oomoo`27Ool00`00Oomoo`3oOol=Ool001Moo`03001oogoo08Qoo`800?moo`eoo`00
5goo00<007ooOol0RWoo00<007ooOol0ogoo2Woo000GOol00`00Oomoo`2;Ool00`00Oomoo`3oOol9
Ool001Moo`03001oogoo08aoo`800?moo`Uoo`005goo00<007ooOol0SWoo00<007ooOol0ogoo1Woo
000GOol00`00Oomoo`2?Ool2003oOol6Ool001Moo`03001oogoo095oo`800?moo`Aoo`005goo00<0
07ooOol0Tgoo00<007ooOol0ogoo0Goo000GOol2002EOol2003oOol1Ool001Moo`03001oogoo09Io
o`800?ioo`005goo00<007ooOol0V7oo0P00o7oo000GOol00`00Oomoo`2JOol00`00Oomoo`3iOol0
01Moo`03001oogoo09]oo`800?Uoo`005goo00<007ooOol0WGoo0P00mgoo000GOol00`00Oomoo`2O
Ool00`00Oomoo`3dOol001Moo`03001oogoo0:1oo`800?Aoo`005goo00<007ooOol0XWoo0P00lWoo
000GOol00`00Oomoo`2TOol2003`Ool001Moo`800:Moo`800>ioo`005goo00<007ooOol0Z7oo0P00
k7oo000GOol00`00Oomoo`2ZOol2003ZOol001Moo`03001oogoo0:aoo`800>Qoo`005goo00<007oo
Ool0[Woo0`00iGoo000GOol00`00Oomoo`2aOol2003SOol001Moo`03001oogoo0;=oo`800>5oo`00
5goo00<007ooOol0]Goo0P00ggoo000GOol00`00Oomoo`2gOol2003MOol001Moo`800;Yoo`800=]o
o`005goo00<007ooOol0^goo0P00fGoo000GOol00`00Oomoo`2mOol3003FOol001Moo`03001oogoo
0<1oo`800=Aoo`005goo00<007ooOol0`Woo0`00dGoo000GOol00`00Oomoo`35Ool2003?Ool000=o
o`05Og8P0000000jo`03Ool01Eg000000000>_l01goo00<007ooOol0agoo0P00cGoo0005Ool00eg0
>_moo`02Ool01eg00MMoogooOg8P03[o00Ioo`03001oogoo0<Uoo`<00<Yoo`001Goo00=M`3[oOol0
1goo00=nkP7GOol01Goo00<007ooOol0c7oo0P00b7oo00000gooKVP0000400000c[oOomoo`05Ool0
0gk^0MMoo`05Ool00`00Oomoo`3>Ool30035Ool00007OomnkP0>Gomooeg0>_l027oo00=903[oOol0
1Goo0`00dGoo0P00`goo0002Ool01FiX0MMooeg0>_l00goo00=omcP000000P0000<RNgooOol01Goo
00<007ooOol0dgoo0`00`7oo0003Ool014T08W]M`3[o0goo00=omcP>Gol02Woo00<007ooOol0eWoo
0`00_Goo0003Ool017mb80PQ03[o0goo00=omcP>Gol02Woo00<007ooOol0fGoo0P00^goo0004Ool0
0gk^000jo`03Ool00gog>000000200000`0>Gomoo`05Ool00`00Oomoo`3KOol3002hOol001Moo`03
001oogoo0=ioo`<00;Eoo`005goo00<007ooOol0hGoo1000/Goo000GOol00`00Oomoo`3UOol3002^
Ool001Moo`03001oogoo0>Qoo`<00:]oo`005goo00<007ooOol0jgoo1000Ygoo000GOol2003`Ool3
002TOol001Moo`03001oogoo0?9oo`@00:1oo`005goo00<007ooOol0mWoo1000W7oo000GOol00`00
Oomoo`3jOol4002HOol001Moo`03001oogoo0?ioo`@009Aoo`005goo00<007ooOol0ogoo0goo1000
T7oo000GOol00`00Oomoo`3oOol7Ool4002<Ool001Moo`03001oogoo0?moo`]oo`@008Qoo`005goo
00<007ooOol0ogoo3goo1000Q7oo000GOol2003oOolDOol40020Ool001Moo`03001oogoo0?mooaMo
o`@007aoo`005goo00<007ooOol0ogoo6goo1000N7oo000GOol00`00Oomoo`3oOolOOol5001cOol0
01Moo`03001oogoo0?moobAoo`D006ioo`005goo00<007ooOol0ogoo:Goo1P00J7oo000GOol00`00
Oomoo`3oOol_Ool5001SOol001Moo`03001oogoo0?moocAoo`H005eoo`005goo00<007ooOol0ogoo
>Woo1P00Egoo000GOol00`00Oomoo`3oOom0Ool6001AOol001Moo`800?moodMoo`P004Uoo`005goo
00<007ooOol0ogooCWoo2000@Goo000GOol00`00Oomoo`3oOomFOol8000iOol001Moo`03001oogoo
0?mooeioo`P0035oo`005goo00<007ooOol0ogooIWoo2000:Goo000GOol00`00Oomoo`3oOom^Ool8
000QOol001Moo`03001oogoo0?moogIoo`P001Uoo`005goo00<007ooOol0ogooOWoo1@0057oo000G
Ool00`00Oomoo`3oOonGOol001Moo`03001oogoo0?mooiMoo`005goo0P00ogooV7oo000GOol00`00
Oomoo`3oOonGOol001Moo`03001oogoo0?mooiMoo`005goo00<007ooOol0ogooUgoo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-15158.7, 22.5124, 984.503, \
0.154489}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g[t], {t, 0, 200000}, 
        PlotRange \[Rule] {All, {20, 50}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76191e-006 -0.412023 0.0206011 [
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -18 -9 ]
[.5 -0.0125 18 0 ]
[.7381 -0.0125 -18 -9 ]
[.7381 -0.0125 18 0 ]
[.97619 -0.0125 -18 -9 ]
[.97619 -0.0125 18 0 ]
[.01131 .10301 -12 -4.5 ]
[.01131 .10301 0 4.5 ]
[.01131 .20601 -12 -4.5 ]
[.01131 .20601 0 4.5 ]
[.01131 .30902 -12 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .41202 -12 -4.5 ]
[.01131 .41202 0 4.5 ]
[.01131 .51503 -12 -4.5 ]
[.01131 .51503 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
[(50000)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100000)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(150000)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(200000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10301 m
.03006 .10301 L
s
[(25)] .01131 .10301 1 0 Mshowa
.02381 .20601 m
.03006 .20601 L
s
[(30)] .01131 .20601 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(35)] .01131 .30902 1 0 Mshowa
.02381 .41202 m
.03006 .41202 L
s
[(40)] .01131 .41202 1 0 Mshowa
.02381 .51503 m
.03006 .51503 L
s
[(45)] .01131 .51503 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(50)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0824 m
.06244 .13121 L
.10458 .17939 L
.14415 .22028 L
.18221 .25601 L
.22272 .29052 L
.26171 .32063 L
.30316 .3496 L
.34309 .37484 L
.3815 .39688 L
.42237 .41814 L
.46172 .43668 L
.49955 .45288 L
.53984 .46854 L
.57861 .48221 L
.61984 .49537 L
.65954 .50685 L
.69774 .51687 L
.73838 .52654 L
.77751 .53498 L
.81909 .5431 L
.85916 .55017 L
.89771 .55634 L
.93871 .56229 L
.97619 .56722 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo001TOol0
1Eg000000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l0
17oo00EnkP00000003[o02ioo`03O^h0000000<000050MMoogooOomnkP0300000c[oOomoo`02Ool0
1Gk^00000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l0
:Woo00=nkP0000000`0000D1egooOomooeg000<00003>_moogoo009oo`05O^h00000000jo`04Ool0
1Gk^00000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`0XOol00gog>00000040000
1C[oOomoogooO^h00`0000<jogooOol00Woo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool0
1Gk^00000000>_l017oo00EnkP00000003[o00Uoo`00Hgoo00MM`07GOomoogmb800jo`03Ool01TT>
Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iO
oc1oo`03B@Q;Ogoo00Aoo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog
>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol/Ool00dT8Bgmoo`03Ool01eg00MMo
ogooOg8P03[o00=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iO
o`=oo`06B@iOogooOoLh3Uoo:7oo00=M`00>Gol00Woo00=^KT]oOol00Woo00I93UooOomomcP>Gol3
Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>Gomo
ogog>0iOo`Qoo`00J7oo00InkP7GOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomn
kP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`0_Ool00dT8Bgmoo`03Ool00gk^0MMoo`02Ool0
1ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogoo
O^h1e`=oo`03KVPRNgoo02]oo`03B@Q;Ogoo00Qoo`06O^h1egooOomnkP7G0goo00I^J29kOomoogk^
0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00=^J29kOol0:7oo00=nkP08Bgl0
1Goo00=nkP7GOol00Woo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomn
kP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`07Ool006Qoo`06O^h1egooOom^J29k0goo00In
kP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol0;goo
00=924]oOol00goo00=^J29kOol00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06
O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0[Ool00dT8Bgmoo`08Ool01Wk^
0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPR
N`=oo`03O^h1egoo02Uoo`03Og8P029k00Aoo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo00In
kP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol01goo
001XOol01TT0>_moogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`03O^h1egoo02moo`03B@Q;Ogoo00=oo`03KVPRNgoo009oo`06O^h1egooOom^
J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=n
kP7GOol0:goo00=924]oOol027oo00I903[oOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1
egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0[Ool00dT08W]oo`02Ool00fiX8W]o
o`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`03O^h1egoo00Moo`00Hgoo00=omcP000000P0000HRNgooOomoofiX8W/3Ool0
1Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^0MMoo`0_
Ool00dT8Bgmoo`03Ool00fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo
00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo02]oo`03B@Q;Ogoo00=oo`03
OoLh0000008000068W]oogooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=o
o`06O^h1egooOom^J29k0goo00=nkP7GOol0;7oo00I93UooOomoofiX8W/3Ool01Wk^0MMoogooKVPR
N`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1
egoo00Moo`00Hgoo00=omcP>Gol01Woo00=nkR9kOol00Woo00I^J29kOomoogk^8W/3Ool01ViX8W]o
ogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00=^J29kOol0;goo00=924]oOol00goo00=nkR9kOol0
0Woo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29k
Oomoogk^8W/3Ool00fiX8W]oo`0[Ool00dT8Bgmoo`03Ool00gog>0iOo`06Ool00gk^8W]oo`02Ool0
1ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool00fiX8W]oo`0W
Ool00fiX>_moo`02Ool01Ug0>_moogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^
8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00=^J29kOol01goo001SOol00gog
>0iOo`07Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool0
1TT0>_moogmb80iOobeoo`05KVP0004BB@Q;O`05Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P
3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo:Goo00E^
J0000A9924]o00Aoo`03OoLh3Uoo00Moo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool0
1TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo:7oo00MnkP0>Gomoogk^00Q;O`03Ool01TT0>_mo
ogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=o
o`06B@0jogooOg8P3Uoo27oo001SOol00gog>000000200000`0>Gomoo`02Ool01Gog>0000008Bgl0
17oo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl0<7oo00=^J008Bgl0
1Goo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP00000
24]o00Aoo`05OoLh000000Q;O`0/Ool00fiX00Q;O`04Ool00gog>000000200000`0>Gomoo`02Ool0
1Gog>0000008Bgl017oo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl0
:Woo00EnkP00000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP00000
24]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl02Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`004Wooo`00R0005goo000K
Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@
Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?
Ool00`00Oomoo`0OOol001]oo`03001oogoo05Yoo`03001oogoo05Yoo`03001oogoo05Yoo`03001o
ogoo05Uoo`03001oogoo01moo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol0
01]oo`03001oogoo0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol0
01]oo`<00?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`03
001oogoo0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`03
001oogoo0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol3003oOonCOol001]oo`03001oogoo
0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`03001oogoo
0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`03001oogoo
0?mooi=oo`006goo0`00ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`03001oogoo0?mooi=o
o`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`03001oogoo0?mooi=o
o`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3oOonCOol001]oo`<00?mooi=oo`006goo
0P00ogooU7oo000KOol00`00Ool0003oOonCOol001]oo`03001oo`000?mooi=oo`006goo00@007oo
Ool00?mooi9oo`001Goo00=omcP00000100000DjogooOomooeg000<00003>_moogoo00Aoo`05001o
ogooOol0003oOonAOol000Ioo`03GL003Uoo009oo`06KVi;OgooOomM`07G0Woo00=oLR00>_l01Goo
00<007ooOol00Woo00<007ooOol0ogooSWoo0007Ool00gk^00Q;O`0:Ool00gk^0MMoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`3oOon=Ool000Qoo`03Og8P029k00Uoo`03O^h1egoo00Aoo`@0009oo`03
001oogoo0?mooheoo`002Woo00=9029kOol01goo00=903[oOol017oo00<007ooOol017oo00<007oo
Ool0ogooS7oo000;Ool01TT>GomoogooOoLh00<000038W]oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo0?mooh]oo`001Woo00=^J3[oOol00Woo00MM`3[oOomoogog>0iOo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`3oOon:Ool000Ioo`07O^h03UooOomnkP08Bgl00Woo00=omcP>Gol02Goo00<007ooOol0
1Woo00<007ooOol0ogooRWoo0007Ool01Gk^00000008Bgl00goo00=omcP000000P0000<03UooOol0
17oo00<007ooOol01goo00<007ooOol0ogooRGoo000KOol00`00Oomoo`08Ool00`00Oomoo`3oOon8
Ool001]oo`03001oogoo00Uoo`03001oogoo0?moohMoo`006goo0`002Woo00<007ooOol0ogooQWoo
000KOol00`00Oomoo`0:Ool00`00Oomoo`3oOon6Ool001]oo`03001oogoo00]oo`03001oogoo0?mo
ohEoo`006goo00<007ooOol037oo00<007ooOol0ogooQ7oo000KOol00`00Oomoo`0=Ool00`00Oomo
o`3oOon3Ool001]oo`03001oogoo00ioo`03001oogoo0?mooh9oo`006goo00<007ooOol03goo00<0
07ooOol0ogooPGoo000KOol00`00Oomoo`0@Ool00`00Oomoo`3oOon0Ool001]oo`<0011oo`03001o
ogoo0?mooh1oo`006goo00<007ooOol04Goo00<007ooOol0ogooOgoo000KOol00`00Oomoo`0BOol0
0`00Oomoo`3oOomnOol001]oo`03001oogoo01=oo`03001oogoo0?moogeoo`006goo00<007ooOol0
57oo00<007ooOol0ogooO7oo000KOol00`00Oomoo`0EOol00`00Oomoo`3oOomkOol001]oo`03001o
ogoo01Ioo`03001oogoo0?moogYoo`006goo00<007ooOol05goo00<007ooOol0ogooNGoo000KOol3
000HOol00`00Oomoo`3oOomhOol001]oo`03001oogoo01Uoo`03001oogoo0?moogMoo`006goo00<0
07ooOol06Goo00<007ooOol0ogooMgoo000KOol00`00Oomoo`0JOol00`00Oomoo`3oOomfOol001]o
o`03001oogoo01]oo`03001oogoo0?moogEoo`006goo00<007ooOol077oo00<007ooOol0ogooM7oo
000KOol00`00Oomoo`0MOol00`00Oomoo`3oOomcOol001]oo`03001oogoo01ioo`03001oogoo0?mo
og9oo`006goo0`007goo00<007ooOol0ogooLGoo000KOol00`00Oomoo`0POol00`00Oomoo`3oOom`
Ool001]oo`03001oogoo025oo`03001oogoo0?moofmoo`006goo00<007ooOol08Woo00<007ooOol0
ogooKWoo000KOol00`00Oomoo`0SOol00`00Oomoo`3oOom]Ool000Moo`05GL000000000RN`04Ool0
1Gk^00000000>_l01Woo00<007ooOol097oo00<007ooOol0ogooK7oo0006Ool01eg00MMoogooOoLh
029k00=oo`06B@iOogooOoLh3Uoo1Goo00<007ooOol097oo00<007ooOol0ogooK7oo000;Ool01Wk^
0MMoogooO^h1e`=oo`03KVPRNgoo00Aoo`03001oogoo02Eoo`03001oogoo0?moof]oo`002Woo00=o
LR08Bgl00Woo00=^J29kOol00Woo00=nkP7GOol017oo10009Goo00<007ooOol0ogooJWoo0008Ool0
16iX000024]o0goo00=^J29kOol00Woo00=nkP7GOol017oo00<007ooOol09goo00<007ooOol0ogoo
JGoo000:Ool00gmb80Q;O`02Ool00fiX8W]oo`02Ool00gk^0MMoo`04Ool00`00Oomoo`0XOol00`00
Oomoo`3oOomXOol000]oo`06GL0jogooOomnkR9k0goo00=^J29kOol017oo00<007ooOol0:Goo00<0
07ooOol0ogooIgoo0006Ool01gk^00Q;OgooOg8P24]o00=oo`06B@0jogooOg8P3Uoo1Goo00<007oo
Ool0:Woo00<007ooOol0ogooIWoo0007Ool01Gmb80000000>_l017oo00EomcP0000024]o00Ioo`03
001oogoo02]oo`03001oogoo0?moofEoo`006goo00<007ooOol0;7oo00<007ooOol0ogooI7oo000K
Ool00`00Oomoo`0]Ool00`00Oomoo`3oOomSOol001]oo`<002ioo`03001oogoo0?moof9oo`006goo
00<007ooOol0;goo00<007ooOol0ogooHGoo000KOol00`00Oomoo`0`Ool00`00Oomoo`3oOomPOol0
01]oo`03001oogoo035oo`03001oogoo0?mooemoo`006goo00<007ooOol0<Woo00<007ooOol0ogoo
GWoo000KOol00`00Oomoo`0cOol2003oOomNOol001]oo`03001oogoo03Eoo`03001oogoo0?mooe]o
o`006goo00<007ooOol0=Woo00<007ooOol0ogooFWoo000KOol3000gOol00`00Oomoo`3oOomIOol0
01]oo`03001oogoo03Qoo`03001oogoo0?mooeQoo`006goo00<007ooOol0>Goo00<007ooOol0ogoo
Egoo000KOol00`00Oomoo`0jOol00`00Oomoo`3oOomFOol001]oo`03001oogoo03]oo`03001oogoo
0?mooeEoo`006goo00<007ooOol0?7oo00<007ooOol0ogooE7oo000KOol00`00Oomoo`0mOol2003o
OomDOol001]oo`03001oogoo03moo`03001oogoo0?mooe5oo`006goo0`00@7oo00<007ooOol0ogoo
D7oo000KOol00`00Oomoo`11Ool00`00Oomoo`3oOom?Ool001]oo`03001oogoo049oo`03001oogoo
0?moodioo`006goo00<007ooOol0@goo0P00ogooCWoo000KOol00`00Oomoo`15Ool00`00Oomoo`3o
Oom;Ool001]oo`03001oogoo04Ioo`03001oogoo0?moodYoo`006goo00<007ooOol0Agoo00<007oo
Ool0ogooBGoo000KOol00`00Oomoo`18Ool2003oOom9Ool001]oo`<004Yoo`03001oogoo0?moodIo
o`006goo00<007ooOol0Bgoo00<007ooOol0ogooAGoo000KOol00`00Oomoo`1<Ool00`00Oomoo`3o
Oom4Ool001]oo`03001oogoo04eoo`800?moodAoo`006goo00<007ooOol0Cgoo00<007ooOol0ogoo
@Goo0007Ool01Eg0000000008W/017oo00EM`000000003[o00Ioo`03001oogoo051oo`03001oogoo
0?mood1oo`001Woo00MM`07GOomoogog>00RN`02Ool01eg00MMoogooOg8P03[o00Eoo`03001oogoo
055oo`03001oogoo0?moocmoo`002goo00=nkP7GOol01Woo00=nkP7GOol017oo00<007ooOol0DWoo
0P00ogoo?goo000:Ool00gmb80Q;O`07Ool00gk^0MMoo`04Ool4001COol00`00Oomoo`3oOollOol0
00Qoo`04KVP00008Bgl8Ool00dT0>_moo`04Ool00`00Oomoo`1EOol00`00Oomoo`3oOolkOol000Yo
o`03Og8P24]o009oo`03OoLh0000008000038W]oogoo00Aoo`03001oogoo05Ioo`03001oogoo0?mo
ocYoo`002goo00MM`3[oOomoogog>0iOo`09Ool00`00Oomoo`1GOol2003oOoljOol000Ioo`07O^h0
24]oOomoLR08Bgl00Woo00=omcP>Gol02Goo00<007ooOol0FGoo00<007ooOol0ogoo=goo0007Ool0
1Gmb80000000>_l00goo00=omcP000000P0000<03UooOol017oo00<007ooOol0FWoo00<007ooOol0
ogoo=Woo000KOol00`00Oomoo`1KOol2003oOolfOol001]oo`03001oogoo05eoo`03001oogoo0?mo
oc=oo`006goo0`00GWoo0P00ogoo<goo000KOol00`00Oomoo`1POol00`00Oomoo`3oOol`Ool001]o
o`03001oogoo065oo`03001oogoo0?moobmoo`006goo00<007ooOol0HWoo0P00ogoo;goo000KOol0
0`00Oomoo`1TOol00`00Oomoo`3oOol/Ool001]oo`03001oogoo06Eoo`800?moobaoo`006goo00<0
07ooOol0Igoo00<007ooOol0ogoo:Goo000KOol00`00Oomoo`1XOol2003oOolYOol001]oo`<006Yo
o`03001oogoo0?moobIoo`006goo00<007ooOol0Jgoo0P00ogoo9Woo000KOol00`00Oomoo`1]Ool0
0`00Oomoo`3oOolSOol001]oo`03001oogoo06ioo`800?moob=oo`006goo00<007ooOol0L7oo0P00
ogoo8Goo000KOol00`00Oomoo`1bOol00`00Oomoo`3oOolNOol001]oo`03001oogoo07=oo`800?mo
oaioo`006goo00<007ooOol0MGoo00<007ooOol0ogoo6goo000KOol3001fOol2003oOolKOol001]o
o`03001oogoo07Qoo`800?mooaUoo`006goo00<007ooOol0NWoo00<007ooOol0ogoo5Woo000KOol0
0`00Oomoo`1kOol2003oOolFOol001]oo`03001oogoo07eoo`800?mooaAoo`006goo00<007ooOol0
Ogoo00<007ooOol0ogoo4Goo000KOol00`00Oomoo`20Ool2003oOolAOol001]oo`03001oogoo089o
o`800?moo`moo`006goo0`00Q7oo00<007ooOol0ogoo37oo000KOol00`00Oomoo`25Ool2003oOol<
Ool001]oo`03001oogoo08Moo`800?moo`Yoo`006goo00<007ooOol0RGoo00<007ooOol0ogoo1goo
000KOol00`00Oomoo`2:Ool2003oOol7Ool000Qoo`05Og8P0000000jo`03Ool01Gk^00000000>_l0
1Woo00<007ooOol0S7oo0P00ogoo1Goo000:Ool00eg0>_moo`03Ool01TT>Gomoogog>0iOo`Eoo`03
001oogoo08ioo`800?moo`=oo`002Woo00=M`3[oOol00Woo00=nkP7GOol00Woo00=^J29kOol017oo
00<007ooOol0T7oo0P00ogoo0Goo0006Ool00fiX0000000300001C[oOomoofiX8W/00goo00=nkP7G
Ool017oo1000TGoo0P00oWoo0006Ool01Wk^00iOogooGL0jo`=oo`03KVPRNgoo009oo`03O^h1egoo
00Aoo`03001oogoo09Aoo`800?aoo`001goo00E^J07GOomM`3[o00=oo`03KVPRNgoo009oo`03O^h1
egoo00Aoo`03001oogoo09Ioo`800?Yoo`0027oo00A9029kGL0jo`=oo`03O^hRNgoo009oo`03KVPR
Ngoo00Aoo`03001oogoo09Qoo`<00?Moo`0027oo00AoLR088@0jo`Aoo`06B@0jogooOg8P3Uoo1Goo
00<007ooOol0Vgoo0P00mGoo0009Ool00gk^000jo`04Ool01Gog>0000008Bgl01Woo00<007ooOol0
WGoo0P00lgoo000KOol00`00Oomoo`2OOol2003aOol001]oo`03001oogoo0:5oo`800>moo`006goo
00<007ooOol0Xgoo0P00kGoo000KOol3002UOol2003[Ool001]oo`03001oogoo0:Moo`<00>Qoo`00
6goo00<007ooOol0ZWoo0P00iWoo000KOol00`00Oomoo`2/Ool3003SOol001]oo`03001oogoo0:mo
o`800>5oo`006goo00<007ooOol0/Goo0`00gWoo000KOol00`00Oomoo`2dOol2003LOol001]oo`03
001oogoo0;Ioo`<00=Uoo`006goo0`00^Goo0P00egoo000KOol00`00Oomoo`2kOol2003EOol001]o
o`03001oogoo0;eoo`800==oo`006goo00<007ooOol0_goo0P00dGoo000KOol00`00Oomoo`31Ool2
003?Ool001]oo`03001oogoo0<=oo`800<eoo`006goo00<007ooOol0aGoo0`00bWoo000KOol00`00
Oomoo`38Ool30037Ool001]oo`<00<]oo`<00<Aoo`006goo00<007ooOol0cWoo1000`7oo000KOol0
0`00Oomoo`3BOol3002mOol001]oo`03001oogoo0=Eoo`<00;Yoo`006goo00<007ooOol0f7oo0`00
]goo000KOol00`00Oomoo`3KOol3002dOol001]oo`03001oogoo0=ioo`@00;1oo`006goo00<007oo
Ool0hWoo0`00[Goo000KOol3003UOol3002ZOol001]oo`03001oogoo0>Qoo`@00:Ioo`006goo00<0
07ooOol0k7oo1000XWoo000KOol00`00Oomoo`3`Ool4002NOol000Qoo`05Og8P0000000jo`03Ool0
1Eg000000000>_l01Woo00<007ooOol0m7oo0`00Vgoo000:Ool00eg0>_moo`02Ool01eg00MMoogoo
Og8P03[o00Eoo`03001oogoo0?Moo`@009Moo`002Woo00=M`3[oOol01goo00=nkP7GOol017oo00<0
07ooOol0ngoo1000Tgoo0006Ool00fiX0000000300000c[oOomoo`05Ool00gk^0MMoo`04Ool00`00
Oomoo`3oOol4002?Ool000Ioo`06O^h03UooOomM`3[o27oo00=903[oOol017oo1000ogoo0goo0`00
S7oo0007Ool01FiX0MMooeg0>_l00goo00=omcP000000P0000<RNgooOol017oo00<007ooOol0ogoo
1goo1000R7oo0008Ool014T08W]M`3[o0goo00=omcP>Gol02Goo00<007ooOol0ogoo2goo1000Q7oo
0008Ool017mb80PQ03[o0goo00=omcP>Gol02Goo00<007ooOol0ogoo3goo1000P7oo0009Ool00gk^
000jo`03Ool00gog>000000200000`0>Gomoo`04Ool00`00Oomoo`3oOolCOol5001kOol001]oo`03
001oogoo0?mooaQoo`D007Ioo`006goo00<007ooOol0ogoo7Goo1@00LGoo000KOol00`00Oomoo`3o
OolROol4001]Ool001]oo`<00?moobIoo`@006Uoo`006goo00<007ooOol0ogoo:Woo1000IGoo000K
Ool00`00Oomoo`3oOol^Ool4001QOol001]oo`03001oogoo0?mooc9oo`H005]oo`006goo00<007oo
Ool0ogoo>7oo2000Dgoo000KOol00`00Oomoo`3oOom0Ool7001<Ool001]oo`03001oogoo0?moodMo
o`D004Moo`006goo00<007ooOol0ogooC7oo1@00@Woo000KOol3003oOomAOol6000lOol001]oo`03
001oogoo0?mooeMoo`P003Aoo`006goo00<007ooOol0ogooGgoo2000;7oo000KOol00`00Oomoo`3o
OomWOol7000UOol001]oo`03001oogoo0?moofioo`@0025oo`006goo00<007ooOol0ogooTgoo000K
Ool00`00Oomoo`3oOonCOol001]oo`03001oogoo0?mooi=oo`006goo0`00ogooTgoo000KOol00`00
Oomoo`3oOonCOol001]oo`03001oogoo0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00
Oomoo`3oOonCOol001]oo`03001oogoo0?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00
Oomoo`3oOonCOol001]oo`<00?mooi=oo`006goo00<007ooOol0ogooTgoo000KOol00`00Oomoo`3o
OonCOol001]oo`03001oogoo0?mooi=oo`001goo00EM`000000003[o00Aoo`05O^h00000000jo`06
Ool00`00Oomoo`3oOonCOol000Ioo`07GL01egooOomoLR00>_l00goo00I93UooOomomcP>Gol5Ool0
0`00Oomoo`3oOonCOol000]oo`06O^h1egooOomnkP7G0goo00=^J29kOol017oo00<007ooOol0ogoo
Tgoo000;Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo00Aoo`03001oogoo0?mooi=oo`002goo00I9
03[oOomoofiX8W/3Ool00gk^0MMoo`04Ool4003oOonBOol000Ioo`03OoLh0000008000068W]oogoo
Oom^J29k0goo00=nkP7GOol0ogooVWoo0006Ool00gog>0iOo`06Ool00gk^8W]oo`02Ool00fiX8W]o
o`3oOonJOol000Ioo`03OoLh3Uoo00Moo`06B@0jogooOg8P3UooogooVgoo0006Ool00gog>0000002
00000`0>Gomoo`02Ool01Gog>0000008Bgl0ogooW7oo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-15059.3, 17.7109, 808.626, \
0.186913}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((g[theta\ 60^2] - T0)\)/\((g[10^7] - T0)\)\)], "Input"],

Cell[BoxData[
    \(0.6811711509847498`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[200\ 10^3]\)], "Input"],

Cell[BoxData[
    \(47.53357407545647`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - 1/E\  // N\)], "Input"],

Cell[BoxData[
    \(0.6321205588285577`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(theta\ 60^2\)], "Input"],

Cell[BoxData[
    \(84913.92`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(10^5/60^2\  // N\)], "Input"],

Cell[BoxData[
    \(27.77777777777778`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trise = rho\ c\ V\ 20/Q\)], "Input"],

Cell[BoxData[
    \(65318.4`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trise/60^2\)], "Input"],

Cell[BoxData[
    \(18.144000000000002`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(z = 
        FindRoot[
          g[t] \[Equal] 20 + Rm\ Q + T0, {t, 
            100}];\)\), "\[IndentingNewLine]", 
    \(triseCcond = z[\([1, 2]\)]\)}], "Input"],

Cell[BoxData[
    \(124512.42841443783`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(triseCcond/60^2 // N\)], "Input"],

Cell[BoxData[
    \(34.58678567067717`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Thermal Time Constant Calculation for Stage 1-2 Actuator Coils & Stage 0-1 \
Actuator Magnet/Frames\
\>", "Section"],

Cell["\<\
Expect that there are small gradients in the Stage 1 aluminum structure (to \
be confirmed with FEA).
Consider a 1/3 sector of the structure associated with a vertical actuator.
Rp = resistance for heat flow from the stage 1 structure, C/W
Rm = resistance for heat flow from the coil to the structure via the actuator \
mount, C/W (assumed to have no significant thermal mass)
R = Rp + Rm = total resistance (at low temperature/power, dominated by \
conduction)
Note: The area associated with the conductance, h, doesn't matter (falls out \
of the equations), so set to unity.\
\>", "Text"],

Cell[BoxData[{
    \(\(Rp = 2.89;\)\), "\[IndentingNewLine]", 
    \(\(Rm = 0.63;\)\), "\[IndentingNewLine]", 
    \(\(R = Rp + Rm;\)\)}], "Input"],

Cell[BoxData[{
    \(\(c = 896;\)\), "\[IndentingNewLine]", 
    \(\(rho = 2700;\)\), "\[IndentingNewLine]", 
    \(\(V = 0.1665/3;\)\), "\[IndentingNewLine]", 
    \(\(A = 4.357/3;\)\), "\[IndentingNewLine]", 
    \(\(h = 1/\((Rp\ A)\);\)\), "\[IndentingNewLine]", 
    \(\(Q = 20;\)\), "\[IndentingNewLine]", 
    \(\(T0 = 20;\)\), "\[IndentingNewLine]", 
    \(\(Tinf = 20;\)\), "\[IndentingNewLine]", 
    \(\(k = 171;\)\)}], "Input"],

Cell[BoxData[{
    \(\(a = h\ A/\((rho\ c\ V)\);\)\), "\[IndentingNewLine]", 
    \(\(b = Q/\((rho\ c\ V)\) + h\ A\ Tinf/\((rho\ c\ V)\);\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(L = V/A\), "\[IndentingNewLine]", 
    \(Bi = h\ L/k\)}], "Input"],

Cell[BoxData[
    \(0.038214367684186366`\)], "Output"],

Cell[BoxData[
    \(0.000053243478317224057`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(diff = k/\((c\ rho)\);\)\), "\[IndentingNewLine]", 
    \(Bi\ diff/L^2\)}], "Input"],

Cell[BoxData[
    \(2.5771363718307197`*^-6\)], "Output"]
}, Open  ]],

Cell["Time constant in hours:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theta = \((rho\ c\ L)\)/\((h\ 60^2)\)\)], "Input"],

Cell[BoxData[
    \(107.78544000000002`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - 1/E\  // N\)], "Input"],

Cell[BoxData[
    \(0.6321205588285577`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(0.63\ 150\  + 20\)], "Input"],

Cell[BoxData[
    \(114.5`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(27.216\ 60^2\)], "Input"],

Cell[BoxData[
    \(97977.6`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f = 
        DSolve[{\(T'\)[t] + a\ T[t]\  == \ b, T[0] \[Equal] T0}, T[t], 
          t];\)\)], "Input"],

Cell[BoxData[
    \(g[t_] := Evaluate[f[\([1, 1, 2]\)] + Q\ Rm]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[g[t]]\)], "Input"],

Cell[BoxData[
    \(\(\(90.4`\)\(\[InvisibleSpace]\)\) - 
      57.80000000000002`\ \[ExponentialE]\^\(\(-2.5771363718307197`*^-6\)\ \
t\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T0 + Q\ R\)], "Input"],

Cell[BoxData[
    \(90.4`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[0]\)], "Input"],

Cell[BoxData[
    \(32.6`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[10^6]\)], "Input"],

Cell[BoxData[
    \(86.00770265311442`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T0 + Q/\((h\ A)\)\)], "Input"],

Cell[BoxData[
    \(77.80000000000001`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Q\ Rm\)], "Input"],

Cell[BoxData[
    \(12.6`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g[t], {t, 0, 3\ theta\ 60^2}, 
        PlotRange \[Rule] {All, {20, 90}}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 8.18139e-007 -0.176581 0.00882906 [
[.18744 -0.0125 -18 -9 ]
[.18744 -0.0125 18 0 ]
[.35106 -0.0125 -18 -9 ]
[.35106 -0.0125 18 0 ]
[.51469 -0.0125 -18 -9 ]
[.51469 -0.0125 18 0 ]
[.67832 -0.0125 -18 -9 ]
[.67832 -0.0125 18 0 ]
[.84195 -0.0125 -14.25 -12.5 ]
[.84195 -0.0125 14.25 0 ]
[.01131 .08829 -12 -4.5 ]
[.01131 .08829 0 4.5 ]
[.01131 .17658 -12 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -12 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -12 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -12 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -12 -4.5 ]
[.01131 .52974 0 4.5 ]
[.01131 .61803 -12 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18744 0 m
.18744 .00625 L
s
[(200000)] .18744 -0.0125 0 1 Mshowa
.35106 0 m
.35106 .00625 L
s
[(400000)] .35106 -0.0125 0 1 Mshowa
.51469 0 m
.51469 .00625 L
s
[(600000)] .51469 -0.0125 0 1 Mshowa
.67832 0 m
.67832 .00625 L
s
[(800000)] .67832 -0.0125 0 1 Mshowa
.84195 0 m
.84195 .00625 L
s
gsave
.84195 -0.0125 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.06472 0 m
.06472 .00375 L
s
.10562 0 m
.10562 .00375 L
s
.14653 0 m
.14653 .00375 L
s
.22834 0 m
.22834 .00375 L
s
.26925 0 m
.26925 .00375 L
s
.31016 0 m
.31016 .00375 L
s
.39197 0 m
.39197 .00375 L
s
.43288 0 m
.43288 .00375 L
s
.47379 0 m
.47379 .00375 L
s
.5556 0 m
.5556 .00375 L
s
.59651 0 m
.59651 .00375 L
s
.63741 0 m
.63741 .00375 L
s
.71923 0 m
.71923 .00375 L
s
.76013 0 m
.76013 .00375 L
s
.80104 0 m
.80104 .00375 L
s
.88286 0 m
.88286 .00375 L
s
.92376 0 m
.92376 .00375 L
s
.96467 0 m
.96467 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08829 m
.03006 .08829 L
s
[(30)] .01131 .08829 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(40)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(50)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(60)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(70)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(80)] .01131 .52974 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(90)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01766 m
.02756 .01766 L
s
.02381 .03532 m
.02756 .03532 L
s
.02381 .05297 m
.02756 .05297 L
s
.02381 .07063 m
.02756 .07063 L
s
.02381 .10595 m
.02756 .10595 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14126 m
.02756 .14126 L
s
.02381 .15892 m
.02756 .15892 L
s
.02381 .19424 m
.02756 .19424 L
s
.02381 .2119 m
.02756 .2119 L
s
.02381 .22956 m
.02756 .22956 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .28253 m
.02756 .28253 L
s
.02381 .30019 m
.02756 .30019 L
s
.02381 .31785 m
.02756 .31785 L
s
.02381 .3355 m
.02756 .3355 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .38848 m
.02756 .38848 L
s
.02381 .40614 m
.02756 .40614 L
s
.02381 .42379 m
.02756 .42379 L
s
.02381 .45911 m
.02756 .45911 L
s
.02381 .47677 m
.02756 .47677 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51209 m
.02756 .51209 L
s
.02381 .5474 m
.02756 .5474 L
s
.02381 .56506 m
.02756 .56506 L
s
.02381 .58272 m
.02756 .58272 L
s
.02381 .60038 m
.02756 .60038 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11125 m
.06244 .16972 L
.10458 .22588 L
.14415 .27226 L
.18221 .31172 L
.22272 .34884 L
.26171 .38036 L
.30316 .40988 L
.34309 .4349 L
.3815 .45617 L
.42237 .47615 L
.46172 .4931 L
.49955 .50754 L
.53984 .52113 L
.57861 .53267 L
.61984 .5435 L
.65954 .55268 L
.69774 .56049 L
.73838 .56783 L
.77751 .57406 L
.81909 .57989 L
.85916 .58483 L
.89771 .58903 L
.93871 .59297 L
.97619 .59616 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOom=Ool00gk^0000000300001@7GOomooeg8Bgl00goo00=njP00
00000`0000D1egooOomoogk^00<00003>_moogoo04Eoo`00ogooD7oo00=924]oOol00goo00YondT8
Bgmoogog>0iOogooB@Q;O`Eoo`06B@iOogooOoLh3UooAWoo001<Ool00gog>000000400001C[oOomo
ogooO^h00`0000<jogooOol00Woo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^0000
0000>_l017oo00EnkP00000003[o00eoo`05Og8P0000000jo`03Ool01Gk^00000000>_l017oo00En
kP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l017oo00EnkP00000003[o00eo
o`05GL00000000iOo`03Ool01Gk^00000000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000j
o`04Ool01Gk^00000000>_l017oo00EnkP00000003[o00eoo`05GL0000000001e`04Ool01Gk^0000
0000>_l017oo00EnkP00000003[o00Aoo`05O^h00000000jo`04Ool01Gk^00000000>_l017oo00En
kP00000003[o01Aoo`03B@Q;Ogoo00Aoo`05Oo]93UokB@iOo`02Ool00dT8Bgmoo`03Ool00gk^0MMo
o`02Ool00fiX8W]oo`15Ool004eoo`03GL003Uoo009oo`03KVi;Ogoo009oo`06B@iOogooOoLh3Uoo
0goo00I93UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93Uoo
OomomcP>Gol>Ool00eg0>_moo`03Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I9
3UooOomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo2goo00I^J07GOomoogk^
0ML3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3Ool01TT>
Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo2goo00=nkP7GOol00Woo00=Mb4]oOol00Woo00I93Uoo
OomomcP>Gol3Ool01TT>Gomoogog>0iOo`=oo`06B@iOogooOoLh3Uoo0goo00I93UooOomomcP>Gol3
Ool01TT>Gomoogog>0iOoa=oo`03B@Q;Ogoo00Eoo`03OoLh24]o00=oo`03B@Q;Ogoo00=oo`03KVPR
Ngoo009oo`03O^h1egoo04Eoo`00CWoo00=nkP08Bgl01Goo00=nkP7GOol00Woo00I^J29kOomoogk^
0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool00fiX
8W]oo`0=Ool00eg0>_moo`02Ool00gk^0MMoo`02Ool01ViX8W]oogooO^h1e`=oo`06KVPRNgooOomn
kP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`03KVPRNgoo00Uoo`03OoLh03[o
009oo`06OoLi4WooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=oo`06KVPR
NgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool00fiX8W]oo`0:Ool00fiX8W]oo`02Ool01Ug0>_mo
ogooO^h1e`=oo`06KVPRNgooOomnkP7G0goo00I^J29kOomoogk^0ML3Ool01ViX8W]oogooO^h1e`=o
o`06KVPRNgooOomnkP7G0goo00=^J29kOol04Woo00=924]oOol017oo00EomcP>Go]924]o009oo`03
B@Q;Ogoo00=oo`03KVPRNgoo009oo`03O^h1egoo04Eoo`00Cgoo00=oLR008W/017oo00=^J29kOol0
0Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7G
OomoofiX8W/3Ool00gk^0MMoo`09Ool00fiX0000000300001C[oOomoofiX8W/00goo00InkP7GOomo
ofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool0
0gk^0MMoo`09Ool01gk^0@Ph3UooOom^J07G009oo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo
00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol0
2Woo00=nkP4BOol00Woo00I924]oOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^
J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo019oo`03B@Q;Ogoo
00=oo`0:OoLh3UooOomondT8BgmoodT8Bgl4Ool00fiX8W]oo`02Ool00gk^0MMoo`15Ool0055oo`03
B@0RNgoo009oo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol02Goo00InkP0>Gomooeg0>_l3Ool0
0fiX8W]oo`02Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3
Ool01Wk^0MMoogooKVPRN`=oo`03O^h1egoo00Uoo`03Og8Q4Wk^008000060A9oogooOom^J29k0goo
00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomo
ofiX8W/3Ool00gk^0MMoo`0;Ool01FiX000000008W/00goo00=^J29kOol00Woo00InkP7GOomoofiX
8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool00gk^
0MMoo`0BOol00dT8Bgmoo`03Ool00eg>Gomoo`02Ool01GokBM9_odT8Bgl017oo00=nkR9kOol00Woo
00=^J29kOol0AGoo001BOol01TT>GomoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00InkP7GOomo
ofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol02Woo00E^J07G
OomM`3[o00=oo`03KVPRNgoo009oo`06O^h1egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^
0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00=nkP7GOol02Goo00=omcP>Gol01Woo00=^J29k
Ool00Woo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k0goo00In
kP7GOomoofiX8W/3Ool00gk^0MMoo`0:Ool00gog>A9oo`02Ool01TT>GomoogooKVPRN`=oo`06O^h1
egooOom^J29k0goo00InkP7GOomoofiX8W/3Ool01Wk^0MMoogooKVPRN`=oo`06O^h1egooOom^J29k
0goo00=nkP7GOol03goo00E^J0000A9924]o00Uoo`05KVP0004BB@Q;O`05Ool01TT0>_moogmb80iO
o`=oo`04KVP000000A8oOol004eoo`03KVPjogoo009oo`06GL0jogooOomnkR9k0goo00I^J29kOomo
ogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool0
0fiX8W]oo`0;Ool014T08W]M`3[o0goo00=nkR9kOol00Woo00I^J29kOomoogk^8W/3Ool01ViX8W]o
ogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29kOomoogk^8W/3Ool00fiX8W]oo`0:Ool00eg0
8W]oo`05Ool00gk^8W]oo`02Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo00I^J29k
Oomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`03KVPRNgoo00Yoo`03O^hRNgoo009oo`06GL0jogoo
OomnkR9k0goo00I^J29kOomoogk^8W/3Ool01ViX8W]oogooO^hRN`=oo`06KVPRNgooOomnkR9k0goo
00I^J29kOomoogk^8W/3Ool00fiX8W]oo`0AOol00fiX00Q;O`0;Ool00fiX00Q;O`05Ool01Gog>000
0008Bgl00goo00IoLR4BOomoofi^BglnOol004eoo`07O^h03UooOomnkP08Bgl00goo00I903[oOomo
LR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool0
1TT0>_moogmb80iOo`aoo`04Og8P2240>_l4Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo
0goo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo2goo00=omcP0
0ML01Woo00I903[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I9
03[oOomoLR0>Gol3Ool01TT0>_moogmb80iOo`]oo`07Og8P3UooOomoLR0>Gol00goo00I903[oOomo
LR0>Gol3Ool01TT0>_moogmb80iOo`=oo`06B@0jogooOg8P3Uoo0goo00I903[oOomoLR0>Gol3Ool0
1TT0>_moogmb80iOoc1oo`06GL014WooOom924]o?Woo001>Ool01Gk^00000008Bgl017oo00EomcP0
000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o00Aoo`05
OoLh000000Q;O`0>Ool00gk^000jo`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o00Aoo`05
OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o00ioo`04GL0000000A83Ool0
1Gog>0000008Bgl017oo00EomcP0000024]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl0
17oo00EomcP0000024]o00eoo`05O^h0000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP00000
24]o00Aoo`05OoLh000000Q;O`04Ool01Gog>0000008Bgl017oo00EomcP0000024]o035oo`05KVhi
b000000RN`0oOol00?moofeoo`03KVPjogoo045oo`00ogooKGoo00=omcP08W/0@Goo003oOom_Ool0
14T0000003[o?Woo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`007gooo`00
O`004goo000XOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0NOol0
02Qoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo
00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo
00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo
00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo
00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo01ioo`00:7oo00<0
07ooOol0?7oo00<007ooOol0>goo00<007ooOol0>goo00<007ooOol0?7oo00<007ooOol0>goo00<0
07ooOol0CGoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007oo
Ool0ogooQWoo000XOol3003oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogoo
QWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogoo
QWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`<00?moohIoo`00:7oo00<007ooOol0ogooQWoo000X
Ool00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000X
Ool00`00Oomoo`3oOon6Ool002Qoo`<00?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00
Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00
Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo0`00ogooQWoo000XOol00`00Oomoo`3o
Oon6Ool002Qoo`03001oogoo0?moohIoo`0057oo00EM`0000000029k00Aoo`05O^h00000000jo`06
Ool00`00Oomoo`3oOon6Ool001=oo`07GL01egooOomomcP08W/00goo00I93UooOomomcP>Gol5Ool0
0`00Oomoo`3oOon6Ool001Qoo`06O^h1egooOomnkP7G0goo00=^J29kOol017oo00<007ooOol0ogoo
QWoo000GOol00gmb80Q;O`02Ool00fiX8W]oo`02Ool00gk^0MMoo`04Ool00`00Oomoo`3oOon6Ool0
01Eoo`04KVP00008Bgl3Ool00fiX8W]oo`02Ool00gk^0MMoo`04Ool4003oOon5Ool001Moo`03Og8P
24]o009oo`03KVPRNgoo009oo`03O^h1egoo00Aoo`03001oogoo0?moohIoo`0067oo00IM`3[oOomo
ogk^8W/3Ool00fiX8W]oo`04Ool00`00Oomoo`3oOon6Ool001=oo`07O^h024]oOomoLR08Bgl00goo
00I903[oOomoLR0>Gol5Ool00`00Oomoo`3oOon6Ool001Aoo`05Og8P0000000jo`04Ool01Gog>000
0008Bgl01Woo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?mo
ohIoo`00:7oo0`00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00
:7oo0P00ogooQgoo000XOol2003oOon7Ool002Qoo`03001oo`000?moohIoo`00:7oo1000ogooQGoo
000XOol01000Oomoo`00ogooQGoo000XOol01@00Oomoogoo0000ogooQ7oo000XOol00`00Oomoo`02
Ool00`00Oomoo`3oOon1Ool002Qoo`03001oogoo009oo`03001oogoo0?mooh5oo`00:7oo00<007oo
Ool00goo00<007ooOol0ogooP7oo000XOol00`00Oomoo`04Ool00`00Oomoo`3oOomoOol002Qoo`<0
00Aoo`03001oogoo0?moogmoo`00:7oo00<007ooOol01Goo00<007ooOol0ogooOWoo000XOol00`00
Oomoo`06Ool00`00Oomoo`3oOommOol002Qoo`03001oogoo00Moo`03001oogoo0?moogaoo`00:7oo
00<007ooOol01goo00<007ooOol0ogooO7oo000XOol00`00Oomoo`08Ool00`00Oomoo`3oOomkOol0
02Qoo`03001oogoo00Uoo`03001oogoo0?moogYoo`00:7oo0`002Goo00<007ooOol0ogooNWoo000X
Ool00`00Oomoo`0:Ool00`00Oomoo`3oOomiOol002Qoo`03001oogoo00]oo`03001oogoo0?moogQo
o`005Goo00EoLR00000003[o00=oo`05O^h00000000jo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3o
OomhOol001Moo`03GL0jogoo00=oo`06B@iOogooOoLh3Uoo1Goo00<007ooOol037oo00<007ooOol0
ogooMgoo000GOol00eg0>_moo`02Ool00gk^0MMoo`02Ool00fiX8W]oo`04Ool00`00Oomoo`0=Ool0
0`00Oomoo`3oOomfOol001=oo`03KVP0000000<00005>_moogooKVPRN`03Ool00gk^0MMoo`04Ool4
000=Ool00`00Oomoo`3oOomeOol001=oo`06O^h03UooOomM`3[o0goo00=^J29kOol00Woo00=nkP7G
Ool017oo00<007ooOol03Woo00<007ooOol0ogooMGoo000DOol01FiX0MMooeg0>_l00goo00=^J29k
Ool00Woo00=nkP7GOol017oo00<007ooOol03goo00<007ooOol0ogooM7oo000EOol014T08W]M`3[o
0goo00=nkR9kOol00Woo00=^J29kOol017oo00<007ooOol047oo00<007ooOol0ogooLgoo000EOol0
17mb80PQ03[o17oo00I903[oOomoLR0>Gol5Ool00`00Oomoo`0AOol00`00Oomoo`3oOombOol001Io
o`03O^h003[o00Aoo`05OoLh000000Q;O`06Ool00`00Oomoo`0AOol00`00Oomoo`3oOombOol002Qo
o`03001oogoo019oo`03001oogoo0?moog5oo`00:7oo0`004goo00<007ooOol0ogooL7oo000XOol0
0`00Oomoo`0DOol00`00Oomoo`3oOom_Ool002Qoo`03001oogoo01Aoo`03001oogoo0?moofmoo`00
:7oo00<007ooOol05Goo00<007ooOol0ogooKWoo000XOol00`00Oomoo`0FOol00`00Oomoo`3oOom]
Ool002Qoo`03001oogoo01Moo`03001oogoo0?moofaoo`00:7oo00<007ooOol05goo00<007ooOol0
ogooK7oo000XOol3000HOol00`00Oomoo`3oOom[Ool002Qoo`03001oogoo01Uoo`03001oogoo0?mo
ofYoo`00:7oo00<007ooOol06Woo00<007ooOol0ogooJGoo000XOol00`00Oomoo`0JOol00`00Oomo
o`3oOomYOol002Qoo`03001oogoo01]oo`03001oogoo0?moofQoo`00:7oo00<007ooOol077oo00<0
07ooOol0ogooIgoo000XOol00`00Oomoo`0MOol00`00Oomoo`3oOomVOol002Qoo`<001ioo`03001o
ogoo0?moofEoo`00:7oo00<007ooOol07Woo00<007ooOol0ogooIGoo000XOol00`00Oomoo`0OOol0
0`00Oomoo`3oOomTOol002Qoo`03001oogoo021oo`03001oogoo0?moof=oo`00:7oo00<007ooOol0
8Goo00<007ooOol0ogooHWoo000XOol00`00Oomoo`0ROol00`00Oomoo`3oOomQOol002Qoo`<002=o
o`03001oogoo0?moof1oo`00:7oo00<007ooOol08goo00<007ooOol0ogooH7oo000XOol00`00Oomo
o`0TOol00`00Oomoo`3oOomOOol002Qoo`03001oogoo02Eoo`03001oogoo0?mooeioo`0057oo00EM
`000000003[o00Aoo`05O^h00000000jo`06Ool00`00Oomoo`0VOol00`00Oomoo`3oOomMOol001=o
o`07GL01egooOomoLR00>_l00goo00I93UooOomomcP>Gol5Ool00`00Oomoo`0WOol00`00Oomoo`3o
OomLOol001Qoo`06O^h1egooOomnkP7G0goo00=^J29kOol017oo00<007ooOol0:7oo00<007ooOol0
ogooFgoo000HOol01Wk^0MMoogooKVPRN`=oo`03O^h1egoo00Aoo`@002Moo`03001oogoo0?mooe]o
o`0067oo00I903[oOomoofiX8W/3Ool00gk^0MMoo`04Ool00`00Oomoo`0YOol00`00Oomoo`3oOomJ
Ool001=oo`03OoLh0000008000068W]oogooOom^J29k0goo00=nkP7GOol017oo00<007ooOol0:Woo
00<007ooOol0ogooFGoo000COol00gog>0iOo`06Ool00gk^8W]oo`02Ool00fiX8W]oo`04Ool00`00
Oomoo`0[Ool00`00Oomoo`3oOomHOol001=oo`03OoLh3Uoo00Moo`06B@0jogooOg8P3Uoo1Goo00<0
07ooOol0;7oo00<007ooOol0ogooEgoo000COol00gog>000000200000`0>Gomoo`02Ool01Gog>000
0008Bgl01Woo00<007ooOol0;Goo00<007ooOol0ogooEWoo000XOol00`00Oomoo`0^Ool00`00Oomo
o`3oOomEOol002Qoo`<002moo`03001oogoo0?mooeAoo`00:7oo00<007ooOol0<7oo00<007ooOol0
ogooDgoo000XOol00`00Oomoo`0aOol00`00Oomoo`3oOomBOol002Qoo`03001oogoo039oo`03001o
ogoo0?mooe5oo`00:7oo00<007ooOol0<goo00<007ooOol0ogooD7oo000XOol00`00Oomoo`0dOol0
0`00Oomoo`3oOom?Ool002Qoo`03001oogoo03Eoo`03001oogoo0?moodioo`00:7oo0`00=Woo00<0
07ooOol0ogooCGoo000XOol00`00Oomoo`0gOol00`00Oomoo`3oOom<Ool002Qoo`03001oogoo03Qo
o`03001oogoo0?mood]oo`00:7oo00<007ooOol0>Goo00<007ooOol0ogooBWoo000XOol00`00Oomo
o`0jOol00`00Oomoo`3oOom9Ool002Qoo`03001oogoo03]oo`03001oogoo0?moodQoo`00:7oo0`00
?7oo00<007ooOol0ogooAgoo000XOol00`00Oomoo`0mOol00`00Oomoo`3oOom6Ool002Qoo`03001o
ogoo03ioo`03001oogoo0?moodEoo`00:7oo00<007ooOol0?goo00<007ooOol0ogooA7oo000XOol0
0`00Oomoo`10Ool00`00Oomoo`3oOom3Ool002Qoo`03001oogoo045oo`800?mood=oo`00:7oo00<0
07ooOol0@goo00<007ooOol0ogoo@7oo000XOol30014Ool00`00Oomoo`3oOoloOol002Qoo`03001o
ogoo04Eoo`03001oogoo0?moocioo`00:7oo00<007ooOol0AWoo00<007ooOol0ogoo?Goo000EOol0
1Eg00000000>Gol00goo00EnkP00000003[o00Ioo`03001oogoo04Moo`03001oogoo0?moocaoo`00
57oo00I^J07GOomoogk^0ML3Ool01TT>Gomoogog>0iOo`Eoo`03001oogoo04Qoo`03001oogoo0?mo
oc]oo`004goo00=omcP0>_l00Woo00IomcTBOomoogk^0ML3Ool00fiX8W]oo`04Ool00`00Oomoo`19
Ool00`00Oomoo`3oOoljOol001=oo`07O^h123P>GomoofiX0ML00Woo00=^J29kOol00Woo00=nkP7G
Ool017oo00<007ooOol0BWoo00<007ooOol0ogoo>Goo000COol00gmb8A9nkP0200001P4BOomoogoo
KVPRN`=oo`03O^h1egoo00Aoo`@004Yoo`800?moocUoo`004goo00=omcP>Gol01Woo00=^J29kOol0
0Woo00=nkP7GOol017oo00<007ooOol0CGoo00<007ooOol0ogoo=Woo000DOol00eg08W]oo`05Ool0
0gk^8W]oo`02Ool00fiX8W]oo`04Ool00`00Oomoo`1>Ool00`00Oomoo`3oOoleOol001Aoo`03OoLh
007G00Ioo`06B@0jogooOg8P3Uoo1Goo00<007ooOol0Cgoo00<007ooOol0ogoo=7oo000FOol015g0
0000004B0goo00EomcP0000024]o00Ioo`03001oogoo051oo`800?moocAoo`00:7oo00<007ooOol0
DWoo00<007ooOol0ogoo<Goo000XOol00`00Oomoo`1COol00`00Oomoo`3oOol`Ool002Qoo`<005Ao
o`03001oogoo0?moobmoo`00:7oo00<007ooOol0EGoo0P00ogoo;goo000XOol00`00Oomoo`1GOol0
0`00Oomoo`3oOol/Ool002Qoo`03001oogoo05Qoo`03001oogoo0?moob]oo`00:7oo00<007ooOol0
FGoo0P00ogoo:goo000XOol00`00Oomoo`1KOol00`00Oomoo`3oOolXOol002Qoo`<005aoo`800?mo
obQoo`00:7oo00<007ooOol0GWoo00<007ooOol0ogoo9Goo000XOol00`00Oomoo`1OOol00`00Oomo
o`3oOolTOol002Qoo`03001oogoo061oo`800?moobAoo`00:7oo00<007ooOol0HWoo00<007ooOol0
ogoo8Goo000XOol00`00Oomoo`1SOol2003oOolQOol002Qoo`03001oogoo06Eoo`03001oogoo0?mo
oaioo`00:7oo0`00IWoo0P00ogoo7Woo000XOol00`00Oomoo`1XOol00`00Oomoo`3oOolKOol002Qo
o`03001oogoo06Uoo`800?mooa]oo`00:7oo00<007ooOol0Jgoo00<007ooOol0ogoo67oo000XOol0
0`00Oomoo`1/Ool2003oOolHOol002Qoo`03001oogoo06ioo`03001oogoo0?mooaEoo`00:7oo00<0
07ooOol0Kgoo0P00ogoo5Goo000XOol3001aOol00`00Oomoo`3oOolBOol002Qoo`03001oogoo079o
o`800?mooa9oo`00:7oo00<007ooOol0M7oo00<007ooOol0ogoo3goo000EOol00gmb8A9oo`05Ool0
1Gk^00000000>_l01Woo00<007ooOol0MGoo0P00ogoo3goo000FOol00dT8Bgmoo`04Ool01TT>Gomo
ogog>0iOo`Eoo`03001oogoo07Moo`03001oogoo0?moo`aoo`005Woo00=^J29kOol00goo00=nkP7G
Ool00Woo00=^J29kOol017oo00<007ooOol0N7oo0P00ogoo37oo000FOol00gmb8A9oo`03Ool00fiX
8W]oo`02Ool00gk^0MMoo`04Ool4001iOol2003oOol:Ool001Moo`03B@Q;Ogoo009oo`03KVPRNgoo
009oo`03O^h1egoo00Aoo`03001oogoo07aoo`800?moo`Qoo`005goo00=^J29kOol00Woo00=^J29k
Ool00Woo00=nkP7GOol017oo00<007ooOol0OWoo0P00ogoo1Woo000GOol00gmb8A9oo`02Ool00gk^
8W]oo`02Ool00fiX8W]oo`04Ool00`00Oomoo`20Ool2003oOol4Ool001=oo`03GLQ;Ogoo009oo`03
GLQ;Ogoo009oo`06B@0jogooOg8P3Uoo1Goo00<007ooOol0PWoo0P00ogoo0Woo000COol00eg00000
000300002C[oOomoogooOoLh000000Q;O`06Ool00`00Oomoo`24Ool2003oOol002Qoo`03001oogoo
08Ioo`03001oogoo0?aoo`00:7oo0`00Qgoo0P00o7oo000XOol00`00Oomoo`29Ool2003jOol002Qo
o`03001oogoo08]oo`800?Qoo`00:7oo00<007ooOol0SGoo0P00mWoo000XOol00`00Oomoo`2?Ool2
003dOol002Qoo`03001oogoo095oo`800?9oo`00:7oo00<007ooOol0Tgoo0P00l7oo000XOol3002E
Ool2003^Ool002Qoo`03001oogoo09Moo`800>aoo`00:7oo00<007ooOol0VGoo0`00jGoo000XOol0
0`00Oomoo`2LOol2003WOol002Qoo`03001oogoo09ioo`<00>Aoo`00:7oo00<007ooOol0XGoo0P00
hWoo000XOol00`00Oomoo`2SOol3003OOol002Qoo`<00:Ioo`800=eoo`00:7oo00<007ooOol0Z7oo
0`00fWoo000XOol00`00Oomoo`2[Ool2003HOol002Qoo`03001oogoo0:eoo`<00=Eoo`00:7oo00<0
07ooOol0/7oo0P00dgoo000XOol00`00Oomoo`2bOol3003@Ool002Qoo`<00;Eoo`<00<eoo`00:7oo
00<007ooOol0^7oo0`00bWoo000XOol00`00Oomoo`2kOol30037Ool002Qoo`03001oogoo0;ioo`<0
0<Aoo`0057oo00EM`0000000007G00Aoo`05O^h00000000jo`06Ool00`00Oomoo`31Ool30031Ool0
01=oo`03O^h1egoo009oo`03GLQ;Ogoo009oo`06B@iOogooOoLh3Uoo1Goo00<007ooOol0a7oo1000
_Goo000COol00fiX8W]oo`02Ool01Ug0>_moogooO^h1e`=oo`03KVPRNgoo00Aoo`03001oogoo0<Qo
o`@00;Uoo`004goo00=nkP4BOol00Woo00I924]oOomoofiX8W/3Ool00gk^0MMoo`04Ool4003;Ool4
002eOol001Aoo`05KVP00000000RN`03Ool00fiX8W]oo`02Ool00gk^0MMoo`04Ool00`00Oomoo`3@
Ool3002bOol001=oo`03OoLi4Woo009oo`06B@iOogooOom^J29k0goo00=nkP7GOol017oo00<007oo
Ool0dgoo1000[Woo000COol00gk^8W]oo`02Ool01Ug0>_moogooO^hRN`=oo`03KVPRNgoo00Aoo`03
001oogoo0=Moo`@00:Yoo`004goo00MoLR0>Gomoogmb80iOo`03Ool01TT0>_moogmb80iOo`Eoo`03
001oogoo0=]oo`@00:Ioo`0057oo00EnkP00000024]o00Aoo`05OoLh000000Q;O`06Ool00`00Oomo
o`3OOol4002ROol002Qoo`03001oogoo0>=oo`@009ioo`00:7oo0`00igoo1000VWoo000XOol00`00
Oomoo`3[Ool4002FOol002Qoo`03001oogoo0>moo`@0099oo`00:7oo00<007ooOol0lgoo1000SWoo
000XOol00`00Oomoo`3gOol50029Ool002Qoo`03001oogoo0?aoo`D008Aoo`00:7oo00<007ooOol0
ogoo0Woo1@00Ogoo000XOol3003oOol7Ool6001iOol002Qoo`03001oogoo0?moo`eoo`H007=oo`00
:7oo00<007ooOol0ogoo4goo2000Jgoo000XOol00`00Oomoo`3oOolKOol7001TOol002Qoo`03001o
ogoo0?moob9oo`P005aoo`00:7oo00<007ooOol0ogoo:Woo1`00EGoo000XOol3003oOolaOol8001=
Ool002Qoo`03001oogoo0?moocUoo`P004Eoo`00:7oo00<007ooOol0ogoo@Goo1`00?Woo000XOol0
0`00Oomoo`3oOom8Ool;000cOol002Qoo`03001oogoo0?mooe=oo`l002Aoo`00:7oo00<007ooOol0
ogooHWoo200077oo000XOol00`00Oomoo`3oOon6Ool002Qoo`<00?moohIoo`00:7oo00<007ooOol0
ogooQWoo000XOol00`00Oomoo`3oOon6Ool001=oo`05Og8P00000001e`05Ool01Gk^00000000>_l0
1Woo00<007ooOol0ogooQWoo000GOol00eg00A9oo`03Ool01TT>Gomoogog>0iOo`Eoo`03001oogoo
0?moohIoo`0067oo00IM`29kOomoogk^0ML3Ool00fiX8W]oo`04Ool00`00Oomoo`3oOon6Ool001Qo
o`06O^h14WooOom^J29k0goo00=nkP7GOol017oo00<007ooOol0ogooQWoo000DOol01Wk^00000000
8LhQ4P9oo`03KVPRNgoo009oo`03O^h1egoo00Aoo`@00?moohEoo`004goo00=omcP8Bgl00Woo00I9
004BOomoofiX8W/3Ool00gk^0MMoo`3oOon=Ool001=oo`03O^h1egoo009oo`06Og8jNgooOomnkR9k
0goo00=^J29kOol0ogooSGoo000COol01gog>0Q;OgooOoLh24]o00=oo`06B@0jogooOg8P3Uooogoo
SWoo000DOol01Gk^00000000>_l017oo00EomcP0000024]o0?moohmoo`00ogoo/Goo003oOonaOol0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-130844, 13.0132, 4809.33, \
0.445654}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((g[theta\ 60^2] - T0)\)/\((g[10^7] - T0)\)\)], "Input"],

Cell[BoxData[
    \(0.6979626179055352`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(theta\ 60^2\)], "Input"],

Cell[BoxData[
    \(388027.5840000001`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(trise = rho\ c\ V\ \(20/Q\)\ /60^2\)], "Input"],

Cell[BoxData[
    \(37.296`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(z = 
        FindRoot[
          g[t] \[Equal] 20 + Rm\ Q + T0, {t, 
            100}];\)\), "\[IndentingNewLine]", 
    \(triseCcond = z[\([1, 2]\)]/60^2\)}], "Input"],

Cell[BoxData[
    \(45.77428529990801`\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 959}},
WindowSize->{1392, 921},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 241, 6, 68, "Input"],
Cell[1998, 59, 54, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[2077, 64, 101, 2, 89, "Section"],
Cell[2181, 68, 153, 2, 68, "Input"],
Cell[2337, 72, 127, 3, 42, "Input"],
Cell[2467, 77, 76, 1, 42, "Input"],
Cell[2546, 80, 47, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2630, 86, 89, 2, 89, "Section"],
Cell[2722, 90, 395, 8, 125, "Text"],
Cell[3120, 100, 145, 3, 94, "Input"],
Cell[3268, 105, 433, 9, 250, "Input"],
Cell[3704, 116, 153, 2, 68, "Input"],

Cell[CellGroupData[{
Cell[3882, 122, 92, 2, 68, "Input"],
Cell[3977, 126, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4067, 132, 107, 2, 68, "Input"],
Cell[4177, 136, 58, 1, 41, "Output"]
}, Open  ]],
Cell[4250, 140, 39, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[4314, 144, 70, 1, 42, "Input"],
Cell[4387, 147, 42, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4466, 153, 47, 1, 42, "Input"],
Cell[4516, 156, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4606, 162, 49, 1, 42, "Input"],
Cell[4658, 165, 40, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4735, 171, 45, 1, 42, "Input"],
Cell[4783, 174, 42, 1, 41, "Output"]
}, Open  ]],
Cell[4840, 178, 127, 3, 42, "Input"],
Cell[4970, 183, 76, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[5071, 188, 47, 1, 42, "Input"],
Cell[5121, 191, 167, 3, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5325, 199, 42, 1, 42, "Input"],
Cell[5370, 202, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5445, 208, 37, 1, 42, "Input"],
Cell[5485, 211, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5560, 217, 40, 1, 42, "Input"],
Cell[5603, 220, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5692, 226, 50, 1, 42, "Input"],
Cell[5745, 229, 38, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5820, 235, 38, 1, 42, "Input"],
Cell[5861, 238, 37, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5935, 244, 104, 2, 42, "Input"],
Cell[6042, 248, 21540, 482, 279, 3600, 256, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27619, 735, 108, 2, 42, "Input"],
Cell[27730, 739, 19866, 462, 279, 3522, 256, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47633, 1206, 77, 1, 42, "Input"],
Cell[47713, 1209, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47803, 1215, 45, 1, 42, "Input"],
Cell[47851, 1218, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47940, 1224, 47, 1, 42, "Input"],
Cell[47990, 1227, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48080, 1233, 44, 1, 42, "Input"],
Cell[48127, 1236, 43, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48207, 1242, 49, 1, 42, "Input"],
Cell[48259, 1245, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48348, 1251, 56, 1, 42, "Input"],
Cell[48407, 1254, 42, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48486, 1260, 43, 1, 42, "Input"],
Cell[48532, 1263, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48622, 1269, 186, 5, 68, "Input"],
Cell[48811, 1276, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48901, 1282, 53, 1, 42, "Input"],
Cell[48957, 1285, 52, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49058, 1292, 126, 3, 89, "Section"],
Cell[49187, 1297, 600, 11, 177, "Text"],
Cell[49790, 1310, 147, 3, 94, "Input"],
Cell[49940, 1315, 438, 9, 250, "Input"],
Cell[50381, 1326, 153, 2, 68, "Input"],

Cell[CellGroupData[{
Cell[50559, 1332, 87, 2, 68, "Input"],
Cell[50649, 1336, 55, 1, 41, "Output"],
Cell[50707, 1339, 58, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50802, 1345, 107, 2, 68, "Input"],
Cell[50912, 1349, 57, 1, 43, "Output"]
}, Open  ]],
Cell[50984, 1353, 39, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[51048, 1357, 70, 1, 42, "Input"],
Cell[51121, 1360, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51211, 1366, 47, 1, 42, "Input"],
Cell[51261, 1369, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51351, 1375, 49, 1, 42, "Input"],
Cell[51403, 1378, 40, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51480, 1384, 45, 1, 42, "Input"],
Cell[51528, 1387, 42, 1, 41, "Output"]
}, Open  ]],
Cell[51585, 1391, 127, 3, 42, "Input"],
Cell[51715, 1396, 76, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[51816, 1401, 47, 1, 42, "Input"],
Cell[51866, 1404, 152, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52055, 1412, 42, 1, 42, "Input"],
Cell[52100, 1415, 39, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52176, 1421, 37, 1, 42, "Input"],
Cell[52216, 1424, 39, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52292, 1430, 40, 1, 42, "Input"],
Cell[52335, 1433, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52424, 1439, 50, 1, 42, "Input"],
Cell[52477, 1442, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52566, 1448, 38, 1, 42, "Input"],
Cell[52607, 1451, 39, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52683, 1457, 116, 2, 42, "Input"],
Cell[52802, 1461, 22698, 531, 279, 4232, 298, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75537, 1997, 77, 1, 42, "Input"],
Cell[75617, 2000, 53, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75707, 2006, 44, 1, 42, "Input"],
Cell[75754, 2009, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75843, 2015, 67, 1, 42, "Input"],
Cell[75913, 2018, 41, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75991, 2024, 191, 5, 68, "Input"],
Cell[76185, 2031, 52, 1, 41, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

